"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_device_pool(projectArn=None, name=None, description=None, rules=None):
    """
    :param projectArn: [REQUIRED]
            The ARN of the project for the device pool.
            
    :type projectArn: string
    :param name: [REQUIRED]
            The device pool's name.
            
    :type name: string
    :param description: The device pool's description.
    :type description: string
    :param rules: [REQUIRED]
            The device pool's rules.
            (dict) --Represents a condition for a device pool.
            attribute (string) --The rule's stringified attribute. For example, specify the value as '\'abc\'' .
            Allowed values include:
            ARN: The ARN.
            FORM_FACTOR: The form factor (for example, phone or tablet).
            MANUFACTURER: The manufacturer.
            PLATFORM: The platform (for example, Android or iOS).
            operator (string) --The rule's operator.
            EQUALS: The equals operator.
            GREATER_THAN: The greater-than operator.
            IN: The in operator.
            LESS_THAN: The less-than operator.
            NOT_IN: The not-in operator.
            value (string) --The rule's value.
            
            
    :type rules: list
    """
    pass

def create_project(name=None):
    """
    :param name: [REQUIRED]
            The project's name.
            Return typedict
            ReturnsResponse Syntax{
              'project': {
                'arn': 'string',
                'name': 'string',
                'created': datetime(2015, 1, 1)
              }
            }
            Response Structure
            (dict) --Represents the result of a create project request.
            project (dict) --The newly created project.
            arn (string) --The project's ARN.
            name (string) --The project's name.
            created (datetime) --When the project was created.
            
            
            
    :type name: string
    """
    pass

def create_remote_access_session(projectArn=None, deviceArn=None, name=None, configuration=None):
    """
    :param projectArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the project for which you want to create a remote access session.
            
    :type projectArn: string
    :param deviceArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the device for which you want to create a remote access session.
            
    :type deviceArn: string
    :param name: The name of the remote access session that you wish to create.
    :type name: string
    :param configuration: The configuration information for the remote access session request.
            billingMethod (string) --Returns the billing method for purposes of configuring a remote access session.
            
    :type configuration: dict
    """
    pass

def create_upload(projectArn=None, name=None, type=None, contentType=None):
    """
    :param projectArn: [REQUIRED]
            The ARN of the project for the upload.
            
    :type projectArn: string
    :param name: [REQUIRED]
            The upload's file name. The name should not contain the '/' character. If uploading an iOS app, the file name needs to end with the .ipa extension. If uploading an Android app, the file name needs to end with the .apk extension. For all others, the file name must end with the .zip file extension.
            
    :type name: string
    :param type: [REQUIRED]
            The upload's upload type.
            Must be one of the following values:
            ANDROID_APP: An Android upload.
            IOS_APP: An iOS upload.
            WEB_APP: A web appliction upload.
            EXTERNAL_DATA: An external data upload.
            APPIUM_JAVA_JUNIT_TEST_PACKAGE: An Appium Java JUnit test package upload.
            APPIUM_JAVA_TESTNG_TEST_PACKAGE: An Appium Java TestNG test package upload.
            APPIUM_PYTHON_TEST_PACKAGE: An Appium Python test package upload.
            APPIUM_WEB_JAVA_JUNIT_TEST_PACKAGE: An Appium Java JUnit test package upload.
            APPIUM_WEB_JAVA_TESTNG_TEST_PACKAGE: An Appium Java TestNG test package upload.
            APPIUM_WEB_PYTHON_TEST_PACKAGE: An Appium Python test package upload.
            CALABASH_TEST_PACKAGE: A Calabash test package upload.
            INSTRUMENTATION_TEST_PACKAGE: An instrumentation upload.
            UIAUTOMATION_TEST_PACKAGE: A uiautomation test package upload.
            UIAUTOMATOR_TEST_PACKAGE: A uiautomator test package upload.
            XCTEST_TEST_PACKAGE: An XCode test package upload.
            XCTEST_UI_TEST_PACKAGE: An XCode UI test package upload.
            Note If you call CreateUpload with WEB_APP specified, AWS Device Farm throws an ArgumentException error.
            
    :type type: string
    :param contentType: The upload's content type (for example, 'application/octet-stream').
    :type contentType: string
    """
    pass

def delete_device_pool(arn=None):
    """
    :param arn: [REQUIRED]
            Represents the Amazon Resource Name (ARN) of the Device Farm device pool you wish to delete.
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --Represents the result of a delete device pool request.
            
            
    :type arn: string
    """
    pass

def delete_project(arn=None):
    """
    :param arn: [REQUIRED]
            Represents the Amazon Resource Name (ARN) of the Device Farm project you wish to delete.
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --Represents the result of a delete project request.
            
            
    :type arn: string
    """
    pass

def delete_remote_access_session(arn=None):
    """
    :param arn: [REQUIRED]
            The Amazon Resource Name (ARN) of the sesssion for which you want to delete remote access.
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --The response from the server when a request is made to delete the remote access session.
            
            
    :type arn: string
    """
    pass

def delete_run(arn=None):
    """
    :param arn: [REQUIRED]
            The Amazon Resource Name (ARN) for the run you wish to delete.
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --Represents the result of a delete run request.
            
            
    :type arn: string
    """
    pass

def delete_upload(arn=None):
    """
    :param arn: [REQUIRED]
            Represents the Amazon Resource Name (ARN) of the Device Farm upload you wish to delete.
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --Represents the result of a delete upload request.
            
            
    :type arn: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_account_settings():
    """
    """
    pass

def get_device(arn=None):
    """
    :param arn: [REQUIRED]
            The device type's ARN.
            Return typedict
            ReturnsResponse Syntax{
              'device': {
                'arn': 'string',
                'name': 'string',
                'manufacturer': 'string',
                'model': 'string',
                'formFactor': 'PHONE'|'TABLET',
                'platform': 'ANDROID'|'IOS',
                'os': 'string',
                'cpu': {
                  'frequency': 'string',
                  'architecture': 'string',
                  'clock': 123.0
                },
                'resolution': {
                  'width': 123,
                  'height': 123
                },
                'heapSize': 123,
                'memory': 123,
                'image': 'string',
                'carrier': 'string',
                'radio': 'string',
                'remoteAccessEnabled': True|False,
                'fleetType': 'string',
                'fleetName': 'string'
              }
            }
            Response Structure
            (dict) --Represents the result of a get device request.
            device (dict) --Represents a device type that an app is tested against.
            arn (string) --The device's ARN.
            name (string) --The device's display name.
            manufacturer (string) --The device's manufacturer name.
            model (string) --The device's model name.
            formFactor (string) --The device's form factor.
            Allowed values include:
            PHONE: The phone form factor.
            TABLET: The tablet form factor.
            platform (string) --The device's platform.
            Allowed values include:
            ANDROID: The Android platform.
            IOS: The iOS platform.
            os (string) --The device's operating system type.
            cpu (dict) --Information about the device's CPU.
            frequency (string) --The CPU's frequency.
            architecture (string) --The CPU's architecture, for example x86 or ARM.
            clock (float) --The clock speed of the device's CPU, expressed in hertz (Hz). For example, a 1.2 GHz CPU is expressed as 1200000000.
            resolution (dict) --Represents the screen resolution of a device in height and width, expressed in pixels.
            width (integer) --The screen resolution's width, expressed in pixels.
            height (integer) --The screen resolution's height, expressed in pixels.
            heapSize (integer) --The device's heap size, expressed in bytes.
            memory (integer) --The device's total memory size, expressed in bytes.
            image (string) --The device's image name.
            carrier (string) --The device's carrier.
            radio (string) --The device's radio.
            remoteAccessEnabled (boolean) --Specifies whether remote access has been enabled for the specified device.
            fleetType (string) --The type of fleet to which this device belongs. Possible values for fleet type are PRIVATE and PUBLIC.
            fleetName (string) --The name of the fleet to which this device belongs.
            
            
            
    :type arn: string
    """
    pass

def get_device_pool(arn=None):
    """
    :param arn: [REQUIRED]
            The device pool's ARN.
            Return typedict
            ReturnsResponse Syntax{
              'devicePool': {
                'arn': 'string',
                'name': 'string',
                'description': 'string',
                'type': 'CURATED'|'PRIVATE',
                'rules': [
                  {
                    'attribute': 'ARN'|'PLATFORM'|'FORM_FACTOR'|'MANUFACTURER'|'REMOTE_ACCESS_ENABLED',
                    'operator': 'EQUALS'|'LESS_THAN'|'GREATER_THAN'|'IN'|'NOT_IN',
                    'value': 'string'
                  },
                ]
              }
            }
            Response Structure
            (dict) --Represents the result of a get device pool request.
            devicePool (dict) --Represents a collection of device types.
            arn (string) --The device pool's ARN.
            name (string) --The device pool's name.
            description (string) --The device pool's description.
            type (string) --The device pool's type.
            Allowed values include:
            CURATED: A device pool that is created and managed by AWS Device Farm.
            PRIVATE: A device pool that is created and managed by the device pool developer.
            rules (list) --Information about the device pool's rules.
            (dict) --Represents a condition for a device pool.
            attribute (string) --The rule's stringified attribute. For example, specify the value as '\'abc\'' .
            Allowed values include:
            ARN: The ARN.
            FORM_FACTOR: The form factor (for example, phone or tablet).
            MANUFACTURER: The manufacturer.
            PLATFORM: The platform (for example, Android or iOS).
            operator (string) --The rule's operator.
            EQUALS: The equals operator.
            GREATER_THAN: The greater-than operator.
            IN: The in operator.
            LESS_THAN: The less-than operator.
            NOT_IN: The not-in operator.
            value (string) --The rule's value.
            
            
            
            
    :type arn: string
    """
    pass

def get_device_pool_compatibility(devicePoolArn=None, appArn=None, testType=None):
    """
    :param devicePoolArn: [REQUIRED]
            The device pool's ARN.
            
    :type devicePoolArn: string
    :param appArn: The ARN of the app that is associated with the specified device pool.
    :type appArn: string
    :param testType: The test type for the specified device pool.
            Allowed values include the following:
            BUILTIN_FUZZ: The built-in fuzz type.
            BUILTIN_EXPLORER: For Android, an app explorer that will traverse an Android app, interacting with it and capturing screenshots at the same time.
            APPIUM_JAVA_JUNIT: The Appium Java JUnit type.
            APPIUM_JAVA_TESTNG: The Appium Java TestNG type.
            APPIUM_PYTHON: The Appium Python type.
            APPIUM_WEB_JAVA_JUNIT: The Appium Java JUnit type for Web apps.
            APPIUM_WEB_JAVA_TESTNG: The Appium Java TestNG type for Web apps.
            APPIUM_WEB_PYTHON: The Appium Python type for Web apps.
            CALABASH: The Calabash type.
            INSTRUMENTATION: The Instrumentation type.
            UIAUTOMATION: The uiautomation type.
            UIAUTOMATOR: The uiautomator type.
            XCTEST: The XCode test type.
            XCTEST_UI: The XCode UI test type.
            
    :type testType: string
    """
    pass

def get_job(arn=None):
    """
    :param arn: [REQUIRED]
            The job's ARN.
            Return typedict
            ReturnsResponse Syntax{
              'job': {
                'arn': 'string',
                'name': 'string',
                'type': 'BUILTIN_FUZZ'|'BUILTIN_EXPLORER'|'APPIUM_JAVA_JUNIT'|'APPIUM_JAVA_TESTNG'|'APPIUM_PYTHON'|'APPIUM_WEB_JAVA_JUNIT'|'APPIUM_WEB_JAVA_TESTNG'|'APPIUM_WEB_PYTHON'|'CALABASH'|'INSTRUMENTATION'|'UIAUTOMATION'|'UIAUTOMATOR'|'XCTEST'|'XCTEST_UI',
                'created': datetime(2015, 1, 1),
                'status': 'PENDING'|'PENDING_CONCURRENCY'|'PENDING_DEVICE'|'PROCESSING'|'SCHEDULING'|'PREPARING'|'RUNNING'|'COMPLETED'|'STOPPING',
                'result': 'PENDING'|'PASSED'|'WARNED'|'FAILED'|'SKIPPED'|'ERRORED'|'STOPPED',
                'started': datetime(2015, 1, 1),
                'stopped': datetime(2015, 1, 1),
                'counters': {
                  'total': 123,
                  'passed': 123,
                  'failed': 123,
                  'warned': 123,
                  'errored': 123,
                  'stopped': 123,
                  'skipped': 123
                },
                'message': 'string',
                'device': {
                  'arn': 'string',
                  'name': 'string',
                  'manufacturer': 'string',
                  'model': 'string',
                  'formFactor': 'PHONE'|'TABLET',
                  'platform': 'ANDROID'|'IOS',
                  'os': 'string',
                  'cpu': {
                    'frequency': 'string',
                    'architecture': 'string',
                    'clock': 123.0
                  },
                  'resolution': {
                    'width': 123,
                    'height': 123
                  },
                  'heapSize': 123,
                  'memory': 123,
                  'image': 'string',
                  'carrier': 'string',
                  'radio': 'string',
                  'remoteAccessEnabled': True|False,
                  'fleetType': 'string',
                  'fleetName': 'string'
                },
                'deviceMinutes': {
                  'total': 123.0,
                  'metered': 123.0,
                  'unmetered': 123.0
                }
              }
            }
            Response Structure
            (dict) --Represents the result of a get job request.
            job (dict) --Represents a device.
            arn (string) --The job's ARN.
            name (string) --The job's name.
            type (string) --The job's type.
            Allowed values include the following:
            BUILTIN_FUZZ: The built-in fuzz type.
            BUILTIN_EXPLORER: For Android, an app explorer that will traverse an Android app, interacting with it and capturing screenshots at the same time.
            APPIUM_JAVA_JUNIT: The Appium Java JUnit type.
            APPIUM_JAVA_TESTNG: The Appium Java TestNG type.
            APPIUM_PYTHON: The Appium Python type.
            APPIUM_WEB_JAVA_JUNIT: The Appium Java JUnit type for Web apps.
            APPIUM_WEB_JAVA_TESTNG: The Appium Java TestNG type for Web apps.
            APPIUM_WEB_PYTHON: The Appium Python type for Web apps.
            CALABASH: The Calabash type.
            INSTRUMENTATION: The Instrumentation type.
            UIAUTOMATION: The uiautomation type.
            UIAUTOMATOR: The uiautomator type.
            XCTEST: The XCode test type.
            XCTEST_UI: The XCode UI test type.
            created (datetime) --When the job was created.
            status (string) --The job's status.
            Allowed values include:
            PENDING: A pending status.
            PENDING_CONCURRENCY: A pending concurrency status.
            PENDING_DEVICE: A pending device status.
            PROCESSING: A processing status.
            SCHEDULING: A scheduling status.
            PREPARING: A preparing status.
            RUNNING: A running status.
            COMPLETED: A completed status.
            STOPPING: A stopping status.
            result (string) --The job's result.
            Allowed values include:
            PENDING: A pending condition.
            PASSED: A passing condition.
            WARNED: A warning condition.
            FAILED: A failed condition.
            SKIPPED: A skipped condition.
            ERRORED: An error condition.
            STOPPED: A stopped condition.
            started (datetime) --The job's start time.
            stopped (datetime) --The job's stop time.
            counters (dict) --The job's result counters.
            total (integer) --The total number of entities.
            passed (integer) --The number of passed entities.
            failed (integer) --The number of failed entities.
            warned (integer) --The number of warned entities.
            errored (integer) --The number of errored entities.
            stopped (integer) --The number of stopped entities.
            skipped (integer) --The number of skipped entities.
            message (string) --A message about the job's result.
            device (dict) --Represents a device type that an app is tested against.
            arn (string) --The device's ARN.
            name (string) --The device's display name.
            manufacturer (string) --The device's manufacturer name.
            model (string) --The device's model name.
            formFactor (string) --The device's form factor.
            Allowed values include:
            PHONE: The phone form factor.
            TABLET: The tablet form factor.
            platform (string) --The device's platform.
            Allowed values include:
            ANDROID: The Android platform.
            IOS: The iOS platform.
            os (string) --The device's operating system type.
            cpu (dict) --Information about the device's CPU.
            frequency (string) --The CPU's frequency.
            architecture (string) --The CPU's architecture, for example x86 or ARM.
            clock (float) --The clock speed of the device's CPU, expressed in hertz (Hz). For example, a 1.2 GHz CPU is expressed as 1200000000.
            resolution (dict) --Represents the screen resolution of a device in height and width, expressed in pixels.
            width (integer) --The screen resolution's width, expressed in pixels.
            height (integer) --The screen resolution's height, expressed in pixels.
            heapSize (integer) --The device's heap size, expressed in bytes.
            memory (integer) --The device's total memory size, expressed in bytes.
            image (string) --The device's image name.
            carrier (string) --The device's carrier.
            radio (string) --The device's radio.
            remoteAccessEnabled (boolean) --Specifies whether remote access has been enabled for the specified device.
            fleetType (string) --The type of fleet to which this device belongs. Possible values for fleet type are PRIVATE and PUBLIC.
            fleetName (string) --The name of the fleet to which this device belongs.
            deviceMinutes (dict) --Represents the total (metered or unmetered) minutes used by the job.
            total (float) --When specified, represents the total minutes used by the resource to run tests.
            metered (float) --When specified, represents only the sum of metered minutes used by the resource to run tests.
            unmetered (float) --When specified, represents only the sum of unmetered minutes used by the resource to run tests.
            
            
            
    :type arn: string
    """
    pass

def get_offering_status(nextToken=None):
    """
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
            Return typedict
            ReturnsResponse Syntax{
              'current': {
                'string': {
                  'type': 'PURCHASE'|'RENEW'|'SYSTEM',
                  'offering': {
                    'id': 'string',
                    'description': 'string',
                    'type': 'RECURRING',
                    'platform': 'ANDROID'|'IOS',
                    'recurringCharges': [
                      {
                        'cost': {
                          'amount': 123.0,
                          'currencyCode': 'USD'
                        },
                        'frequency': 'MONTHLY'
                      },
                    ]
                  },
                  'quantity': 123,
                  'effectiveOn': datetime(2015, 1, 1)
                }
              },
              'nextPeriod': {
                'string': {
                  'type': 'PURCHASE'|'RENEW'|'SYSTEM',
                  'offering': {
                    'id': 'string',
                    'description': 'string',
                    'type': 'RECURRING',
                    'platform': 'ANDROID'|'IOS',
                    'recurringCharges': [
                      {
                        'cost': {
                          'amount': 123.0,
                          'currencyCode': 'USD'
                        },
                        'frequency': 'MONTHLY'
                      },
                    ]
                  },
                  'quantity': 123,
                  'effectiveOn': datetime(2015, 1, 1)
                }
              },
              'nextToken': 'string'
            }
            Response Structure
            (dict) --Returns the status result for a device offering.
            current (dict) --When specified, gets the offering status for the current period.
            (string) --
            (dict) --The status of the offering.
            type (string) --The type specified for the offering status.
            offering (dict) --Represents the metadata of an offering status.
            id (string) --The ID that corresponds to a device offering.
            description (string) --A string describing the offering.
            type (string) --The type of offering (e.g., 'RECURRING') for a device.
            platform (string) --The platform of the device (e.g., ANDROID or IOS).
            recurringCharges (list) --Specifies whether there are recurring charges for the offering.
            (dict) --Specifies whether charges for devices will be recurring.
            cost (dict) --The cost of the recurring charge.
            amount (float) --The numerical amount of an offering or transaction.
            currencyCode (string) --The currency code of a monetary amount. For example, USD means 'U.S. dollars.'
            frequency (string) --The frequency in which charges will recur.
            
            quantity (integer) --The number of available devices in the offering.
            effectiveOn (datetime) --The date on which the offering is effective.
            
            nextPeriod (dict) --When specified, gets the offering status for the next period.
            (string) --
            (dict) --The status of the offering.
            type (string) --The type specified for the offering status.
            offering (dict) --Represents the metadata of an offering status.
            id (string) --The ID that corresponds to a device offering.
            description (string) --A string describing the offering.
            type (string) --The type of offering (e.g., 'RECURRING') for a device.
            platform (string) --The platform of the device (e.g., ANDROID or IOS).
            recurringCharges (list) --Specifies whether there are recurring charges for the offering.
            (dict) --Specifies whether charges for devices will be recurring.
            cost (dict) --The cost of the recurring charge.
            amount (float) --The numerical amount of an offering or transaction.
            currencyCode (string) --The currency code of a monetary amount. For example, USD means 'U.S. dollars.'
            frequency (string) --The frequency in which charges will recur.
            
            quantity (integer) --The number of available devices in the offering.
            effectiveOn (datetime) --The date on which the offering is effective.
            
            nextToken (string) --An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
            
            
    :type nextToken: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_project(arn=None):
    """
    :param arn: [REQUIRED]
            The project's ARN.
            Return typedict
            ReturnsResponse Syntax{
              'project': {
                'arn': 'string',
                'name': 'string',
                'created': datetime(2015, 1, 1)
              }
            }
            Response Structure
            (dict) --Represents the result of a get project request.
            project (dict) --Represents an operating-system neutral workspace for running and managing tests.
            arn (string) --The project's ARN.
            name (string) --The project's name.
            created (datetime) --When the project was created.
            
            
            
    :type arn: string
    """
    pass

def get_remote_access_session(arn=None):
    """
    :param arn: [REQUIRED]
            The Amazon Resource Name (ARN) of the remote access session about which you want to get session information.
            Return typedict
            ReturnsResponse Syntax{
              'remoteAccessSession': {
                'arn': 'string',
                'name': 'string',
                'created': datetime(2015, 1, 1),
                'status': 'PENDING'|'PENDING_CONCURRENCY'|'PENDING_DEVICE'|'PROCESSING'|'SCHEDULING'|'PREPARING'|'RUNNING'|'COMPLETED'|'STOPPING',
                'result': 'PENDING'|'PASSED'|'WARNED'|'FAILED'|'SKIPPED'|'ERRORED'|'STOPPED',
                'message': 'string',
                'started': datetime(2015, 1, 1),
                'stopped': datetime(2015, 1, 1),
                'device': {
                  'arn': 'string',
                  'name': 'string',
                  'manufacturer': 'string',
                  'model': 'string',
                  'formFactor': 'PHONE'|'TABLET',
                  'platform': 'ANDROID'|'IOS',
                  'os': 'string',
                  'cpu': {
                    'frequency': 'string',
                    'architecture': 'string',
                    'clock': 123.0
                  },
                  'resolution': {
                    'width': 123,
                    'height': 123
                  },
                  'heapSize': 123,
                  'memory': 123,
                  'image': 'string',
                  'carrier': 'string',
                  'radio': 'string',
                  'remoteAccessEnabled': True|False,
                  'fleetType': 'string',
                  'fleetName': 'string'
                },
                'billingMethod': 'METERED'|'UNMETERED',
                'deviceMinutes': {
                  'total': 123.0,
                  'metered': 123.0,
                  'unmetered': 123.0
                },
                'endpoint': 'string'
              }
            }
            Response Structure
            (dict) --Represents the response from the server that lists detailed information about the remote access session.
            remoteAccessSession (dict) --A container that lists detailed information about the remote access session.
            arn (string) --The Amazon Resource Name (ARN) of the remote access session.
            name (string) --The name of the remote access session.
            created (datetime) --The date and time the remote access session was created.
            status (string) --The status of the remote access session. Can be any of the following:
            PENDING: A pending status.
            PENDING_CONCURRENCY: A pending concurrency status.
            PENDING_DEVICE: A pending device status.
            PROCESSING: A processing status.
            SCHEDULING: A scheduling status.
            PREPARING: A preparing status.
            RUNNING: A running status.
            COMPLETED: A completed status.
            STOPPING: A stopping status.
            result (string) --The result of the remote access session. Can be any of the following:
            PENDING: A pending condition.
            PASSED: A passing condition.
            WARNED: A warning condition.
            FAILED: A failed condition.
            SKIPPED: A skipped condition.
            ERRORED: An error condition.
            STOPPED: A stopped condition.
            message (string) --A message about the remote access session.
            started (datetime) --The date and time the remote access session was started.
            stopped (datetime) --The date and time the remote access session was stopped.
            device (dict) --Represents a device type that an app is tested against.
            arn (string) --The device's ARN.
            name (string) --The device's display name.
            manufacturer (string) --The device's manufacturer name.
            model (string) --The device's model name.
            formFactor (string) --The device's form factor.
            Allowed values include:
            PHONE: The phone form factor.
            TABLET: The tablet form factor.
            platform (string) --The device's platform.
            Allowed values include:
            ANDROID: The Android platform.
            IOS: The iOS platform.
            os (string) --The device's operating system type.
            cpu (dict) --Information about the device's CPU.
            frequency (string) --The CPU's frequency.
            architecture (string) --The CPU's architecture, for example x86 or ARM.
            clock (float) --The clock speed of the device's CPU, expressed in hertz (Hz). For example, a 1.2 GHz CPU is expressed as 1200000000.
            resolution (dict) --Represents the screen resolution of a device in height and width, expressed in pixels.
            width (integer) --The screen resolution's width, expressed in pixels.
            height (integer) --The screen resolution's height, expressed in pixels.
            heapSize (integer) --The device's heap size, expressed in bytes.
            memory (integer) --The device's total memory size, expressed in bytes.
            image (string) --The device's image name.
            carrier (string) --The device's carrier.
            radio (string) --The device's radio.
            remoteAccessEnabled (boolean) --Specifies whether remote access has been enabled for the specified device.
            fleetType (string) --The type of fleet to which this device belongs. Possible values for fleet type are PRIVATE and PUBLIC.
            fleetName (string) --The name of the fleet to which this device belongs.
            billingMethod (string) --The billing method of the remote access session. Possible values include METERED or UNMETERED . For more information about metered devices, see AWS Device Farm terminology .'
            deviceMinutes (dict) --Represents the total (metered or unmetered) minutes used by the resource to run tests. Contains the sum of minutes consumed by all children.
            total (float) --When specified, represents the total minutes used by the resource to run tests.
            metered (float) --When specified, represents only the sum of metered minutes used by the resource to run tests.
            unmetered (float) --When specified, represents only the sum of unmetered minutes used by the resource to run tests.
            endpoint (string) --The endpoint for the remote access sesssion.
            
            
            
    :type arn: string
    """
    pass

def get_run(arn=None):
    """
    :param arn: [REQUIRED]
            The run's ARN.
            Return typedict
            ReturnsResponse Syntax{
              'run': {
                'arn': 'string',
                'name': 'string',
                'type': 'BUILTIN_FUZZ'|'BUILTIN_EXPLORER'|'APPIUM_JAVA_JUNIT'|'APPIUM_JAVA_TESTNG'|'APPIUM_PYTHON'|'APPIUM_WEB_JAVA_JUNIT'|'APPIUM_WEB_JAVA_TESTNG'|'APPIUM_WEB_PYTHON'|'CALABASH'|'INSTRUMENTATION'|'UIAUTOMATION'|'UIAUTOMATOR'|'XCTEST'|'XCTEST_UI',
                'platform': 'ANDROID'|'IOS',
                'created': datetime(2015, 1, 1),
                'status': 'PENDING'|'PENDING_CONCURRENCY'|'PENDING_DEVICE'|'PROCESSING'|'SCHEDULING'|'PREPARING'|'RUNNING'|'COMPLETED'|'STOPPING',
                'result': 'PENDING'|'PASSED'|'WARNED'|'FAILED'|'SKIPPED'|'ERRORED'|'STOPPED',
                'started': datetime(2015, 1, 1),
                'stopped': datetime(2015, 1, 1),
                'counters': {
                  'total': 123,
                  'passed': 123,
                  'failed': 123,
                  'warned': 123,
                  'errored': 123,
                  'stopped': 123,
                  'skipped': 123
                },
                'message': 'string',
                'totalJobs': 123,
                'completedJobs': 123,
                'billingMethod': 'METERED'|'UNMETERED',
                'deviceMinutes': {
                  'total': 123.0,
                  'metered': 123.0,
                  'unmetered': 123.0
                }
              }
            }
            Response Structure
            (dict) --Represents the result of a get run request.
            run (dict) --Represents an app on a set of devices with a specific test and configuration.
            arn (string) --The run's ARN.
            name (string) --The run's name.
            type (string) --The run's type.
            Must be one of the following values:
            BUILTIN_FUZZ: The built-in fuzz type.
            BUILTIN_EXPLORER: For Android, an app explorer that will traverse an Android app, interacting with it and capturing screenshots at the same time.
            APPIUM_JAVA_JUNIT: The Appium Java JUnit type.
            APPIUM_JAVA_TESTNG: The Appium Java TestNG type.
            APPIUM_PYTHON: The Appium Python type.
            APPIUM_WEB_JAVA_JUNIT: The Appium Java JUnit type for Web apps.
            APPIUM_WEB_JAVA_TESTNG: The Appium Java TestNG type for Web apps.
            APPIUM_WEB_PYTHON: The Appium Python type for Web apps.
            CALABASH: The Calabash type.
            INSTRUMENTATION: The Instrumentation type.
            UIAUTOMATION: The uiautomation type.
            UIAUTOMATOR: The uiautomator type.
            XCTEST: The XCode test type.
            XCTEST_UI: The XCode UI test type.
            platform (string) --The run's platform.
            Allowed values include:
            ANDROID: The Android platform.
            IOS: The iOS platform.
            created (datetime) --When the run was created.
            status (string) --The run's status.
            Allowed values include:
            PENDING: A pending status.
            PENDING_CONCURRENCY: A pending concurrency status.
            PENDING_DEVICE: A pending device status.
            PROCESSING: A processing status.
            SCHEDULING: A scheduling status.
            PREPARING: A preparing status.
            RUNNING: A running status.
            COMPLETED: A completed status.
            STOPPING: A stopping status.
            result (string) --The run's result.
            Allowed values include:
            PENDING: A pending condition.
            PASSED: A passing condition.
            WARNED: A warning condition.
            FAILED: A failed condition.
            SKIPPED: A skipped condition.
            ERRORED: An error condition.
            STOPPED: A stopped condition.
            started (datetime) --The run's start time.
            stopped (datetime) --The run's stop time.
            counters (dict) --The run's result counters.
            total (integer) --The total number of entities.
            passed (integer) --The number of passed entities.
            failed (integer) --The number of failed entities.
            warned (integer) --The number of warned entities.
            errored (integer) --The number of errored entities.
            stopped (integer) --The number of stopped entities.
            skipped (integer) --The number of skipped entities.
            message (string) --A message about the run's result.
            totalJobs (integer) --The total number of jobs for the run.
            completedJobs (integer) --The total number of completed jobs.
            billingMethod (string) --Specifies the billing method for a test run: metered or unmetered . If the parameter is not specified, the default value is metered .
            deviceMinutes (dict) --Represents the total (metered or unmetered) minutes used by the test run.
            total (float) --When specified, represents the total minutes used by the resource to run tests.
            metered (float) --When specified, represents only the sum of metered minutes used by the resource to run tests.
            unmetered (float) --When specified, represents only the sum of unmetered minutes used by the resource to run tests.
            
            
            
    :type arn: string
    """
    pass

def get_suite(arn=None):
    """
    :param arn: [REQUIRED]
            The suite's ARN.
            Return typedict
            ReturnsResponse Syntax{
              'suite': {
                'arn': 'string',
                'name': 'string',
                'type': 'BUILTIN_FUZZ'|'BUILTIN_EXPLORER'|'APPIUM_JAVA_JUNIT'|'APPIUM_JAVA_TESTNG'|'APPIUM_PYTHON'|'APPIUM_WEB_JAVA_JUNIT'|'APPIUM_WEB_JAVA_TESTNG'|'APPIUM_WEB_PYTHON'|'CALABASH'|'INSTRUMENTATION'|'UIAUTOMATION'|'UIAUTOMATOR'|'XCTEST'|'XCTEST_UI',
                'created': datetime(2015, 1, 1),
                'status': 'PENDING'|'PENDING_CONCURRENCY'|'PENDING_DEVICE'|'PROCESSING'|'SCHEDULING'|'PREPARING'|'RUNNING'|'COMPLETED'|'STOPPING',
                'result': 'PENDING'|'PASSED'|'WARNED'|'FAILED'|'SKIPPED'|'ERRORED'|'STOPPED',
                'started': datetime(2015, 1, 1),
                'stopped': datetime(2015, 1, 1),
                'counters': {
                  'total': 123,
                  'passed': 123,
                  'failed': 123,
                  'warned': 123,
                  'errored': 123,
                  'stopped': 123,
                  'skipped': 123
                },
                'message': 'string',
                'deviceMinutes': {
                  'total': 123.0,
                  'metered': 123.0,
                  'unmetered': 123.0
                }
              }
            }
            Response Structure
            (dict) --Represents the result of a get suite request.
            suite (dict) --Represents a collection of one or more tests.
            arn (string) --The suite's ARN.
            name (string) --The suite's name.
            type (string) --The suite's type.
            Must be one of the following values:
            BUILTIN_FUZZ: The built-in fuzz type.
            BUILTIN_EXPLORER: For Android, an app explorer that will traverse an Android app, interacting with it and capturing screenshots at the same time.
            APPIUM_JAVA_JUNIT: The Appium Java JUnit type.
            APPIUM_JAVA_TESTNG: The Appium Java TestNG type.
            APPIUM_PYTHON: The Appium Python type.
            APPIUM_WEB_JAVA_JUNIT: The Appium Java JUnit type for Web apps.
            APPIUM_WEB_JAVA_TESTNG: The Appium Java TestNG type for Web apps.
            APPIUM_WEB_PYTHON: The Appium Python type for Web apps.
            CALABASH: The Calabash type.
            INSTRUMENTATION: The Instrumentation type.
            UIAUTOMATION: The uiautomation type.
            UIAUTOMATOR: The uiautomator type.
            XCTEST: The XCode test type.
            XCTEST_UI: The XCode UI test type.
            created (datetime) --When the suite was created.
            status (string) --The suite's status.
            Allowed values include:
            PENDING: A pending status.
            PENDING_CONCURRENCY: A pending concurrency status.
            PENDING_DEVICE: A pending device status.
            PROCESSING: A processing status.
            SCHEDULING: A scheduling status.
            PREPARING: A preparing status.
            RUNNING: A running status.
            COMPLETED: A completed status.
            STOPPING: A stopping status.
            result (string) --The suite's result.
            Allowed values include:
            PENDING: A pending condition.
            PASSED: A passing condition.
            WARNED: A warning condition.
            FAILED: A failed condition.
            SKIPPED: A skipped condition.
            ERRORED: An error condition.
            STOPPED: A stopped condition.
            started (datetime) --The suite's start time.
            stopped (datetime) --The suite's stop time.
            counters (dict) --The suite's result counters.
            total (integer) --The total number of entities.
            passed (integer) --The number of passed entities.
            failed (integer) --The number of failed entities.
            warned (integer) --The number of warned entities.
            errored (integer) --The number of errored entities.
            stopped (integer) --The number of stopped entities.
            skipped (integer) --The number of skipped entities.
            message (string) --A message about the suite's result.
            deviceMinutes (dict) --Represents the total (metered or unmetered) minutes used by the test suite.
            total (float) --When specified, represents the total minutes used by the resource to run tests.
            metered (float) --When specified, represents only the sum of metered minutes used by the resource to run tests.
            unmetered (float) --When specified, represents only the sum of unmetered minutes used by the resource to run tests.
            
            
            
    :type arn: string
    """
    pass

def get_test(arn=None):
    """
    :param arn: [REQUIRED]
            The test's ARN.
            Return typedict
            ReturnsResponse Syntax{
              'test': {
                'arn': 'string',
                'name': 'string',
                'type': 'BUILTIN_FUZZ'|'BUILTIN_EXPLORER'|'APPIUM_JAVA_JUNIT'|'APPIUM_JAVA_TESTNG'|'APPIUM_PYTHON'|'APPIUM_WEB_JAVA_JUNIT'|'APPIUM_WEB_JAVA_TESTNG'|'APPIUM_WEB_PYTHON'|'CALABASH'|'INSTRUMENTATION'|'UIAUTOMATION'|'UIAUTOMATOR'|'XCTEST'|'XCTEST_UI',
                'created': datetime(2015, 1, 1),
                'status': 'PENDING'|'PENDING_CONCURRENCY'|'PENDING_DEVICE'|'PROCESSING'|'SCHEDULING'|'PREPARING'|'RUNNING'|'COMPLETED'|'STOPPING',
                'result': 'PENDING'|'PASSED'|'WARNED'|'FAILED'|'SKIPPED'|'ERRORED'|'STOPPED',
                'started': datetime(2015, 1, 1),
                'stopped': datetime(2015, 1, 1),
                'counters': {
                  'total': 123,
                  'passed': 123,
                  'failed': 123,
                  'warned': 123,
                  'errored': 123,
                  'stopped': 123,
                  'skipped': 123
                },
                'message': 'string',
                'deviceMinutes': {
                  'total': 123.0,
                  'metered': 123.0,
                  'unmetered': 123.0
                }
              }
            }
            Response Structure
            (dict) --Represents the result of a get test request.
            test (dict) --Represents a condition that is evaluated.
            arn (string) --The test's ARN.
            name (string) --The test's name.
            type (string) --The test's type.
            Must be one of the following values:
            BUILTIN_FUZZ: The built-in fuzz type.
            BUILTIN_EXPLORER: For Android, an app explorer that will traverse an Android app, interacting with it and capturing screenshots at the same time.
            APPIUM_JAVA_JUNIT: The Appium Java JUnit type.
            APPIUM_JAVA_TESTNG: The Appium Java TestNG type.
            APPIUM_PYTHON: The Appium Python type.
            APPIUM_WEB_JAVA_JUNIT: The Appium Java JUnit type for Web apps.
            APPIUM_WEB_JAVA_TESTNG: The Appium Java TestNG type for Web apps.
            APPIUM_WEB_PYTHON: The Appium Python type for Web apps.
            CALABASH: The Calabash type.
            INSTRUMENTATION: The Instrumentation type.
            UIAUTOMATION: The uiautomation type.
            UIAUTOMATOR: The uiautomator type.
            XCTEST: The XCode test type.
            XCTEST_UI: The XCode UI test type.
            created (datetime) --When the test was created.
            status (string) --The test's status.
            Allowed values include:
            PENDING: A pending status.
            PENDING_CONCURRENCY: A pending concurrency status.
            PENDING_DEVICE: A pending device status.
            PROCESSING: A processing status.
            SCHEDULING: A scheduling status.
            PREPARING: A preparing status.
            RUNNING: A running status.
            COMPLETED: A completed status.
            STOPPING: A stopping status.
            result (string) --The test's result.
            Allowed values include:
            PENDING: A pending condition.
            PASSED: A passing condition.
            WARNED: A warning condition.
            FAILED: A failed condition.
            SKIPPED: A skipped condition.
            ERRORED: An error condition.
            STOPPED: A stopped condition.
            started (datetime) --The test's start time.
            stopped (datetime) --The test's stop time.
            counters (dict) --The test's result counters.
            total (integer) --The total number of entities.
            passed (integer) --The number of passed entities.
            failed (integer) --The number of failed entities.
            warned (integer) --The number of warned entities.
            errored (integer) --The number of errored entities.
            stopped (integer) --The number of stopped entities.
            skipped (integer) --The number of skipped entities.
            message (string) --A message about the test's result.
            deviceMinutes (dict) --Represents the total (metered or unmetered) minutes used by the test.
            total (float) --When specified, represents the total minutes used by the resource to run tests.
            metered (float) --When specified, represents only the sum of metered minutes used by the resource to run tests.
            unmetered (float) --When specified, represents only the sum of unmetered minutes used by the resource to run tests.
            
            
            
    :type arn: string
    """
    pass

def get_upload(arn=None):
    """
    :param arn: [REQUIRED]
            The upload's ARN.
            Return typedict
            ReturnsResponse Syntax{
              'upload': {
                'arn': 'string',
                'name': 'string',
                'created': datetime(2015, 1, 1),
                'type': 'ANDROID_APP'|'IOS_APP'|'WEB_APP'|'EXTERNAL_DATA'|'APPIUM_JAVA_JUNIT_TEST_PACKAGE'|'APPIUM_JAVA_TESTNG_TEST_PACKAGE'|'APPIUM_PYTHON_TEST_PACKAGE'|'APPIUM_WEB_JAVA_JUNIT_TEST_PACKAGE'|'APPIUM_WEB_JAVA_TESTNG_TEST_PACKAGE'|'APPIUM_WEB_PYTHON_TEST_PACKAGE'|'CALABASH_TEST_PACKAGE'|'INSTRUMENTATION_TEST_PACKAGE'|'UIAUTOMATION_TEST_PACKAGE'|'UIAUTOMATOR_TEST_PACKAGE'|'XCTEST_TEST_PACKAGE'|'XCTEST_UI_TEST_PACKAGE',
                'status': 'INITIALIZED'|'PROCESSING'|'SUCCEEDED'|'FAILED',
                'url': 'string',
                'metadata': 'string',
                'contentType': 'string',
                'message': 'string'
              }
            }
            Response Structure
            (dict) --Represents the result of a get upload request.
            upload (dict) --An app or a set of one or more tests to upload or that have been uploaded.
            arn (string) --The upload's ARN.
            name (string) --The upload's file name.
            created (datetime) --When the upload was created.
            type (string) --The upload's type.
            Must be one of the following values:
            ANDROID_APP: An Android upload.
            IOS_APP: An iOS upload.
            WEB_APP: A web appliction upload.
            EXTERNAL_DATA: An external data upload.
            APPIUM_JAVA_JUNIT_TEST_PACKAGE: An Appium Java JUnit test package upload.
            APPIUM_JAVA_TESTNG_TEST_PACKAGE: An Appium Java TestNG test package upload.
            APPIUM_PYTHON_TEST_PACKAGE: An Appium Python test package upload.
            APPIUM_WEB_JAVA_JUNIT_TEST_PACKAGE: An Appium Java JUnit test package upload.
            APPIUM_WEB_JAVA_TESTNG_TEST_PACKAGE: An Appium Java TestNG test package upload.
            APPIUM_WEB_PYTHON_TEST_PACKAGE: An Appium Python test package upload.
            CALABASH_TEST_PACKAGE: A Calabash test package upload.
            INSTRUMENTATION_TEST_PACKAGE: An instrumentation upload.
            UIAUTOMATION_TEST_PACKAGE: A uiautomation test package upload.
            UIAUTOMATOR_TEST_PACKAGE: A uiautomator test package upload.
            XCTEST_TEST_PACKAGE: An XCode test package upload.
            XCTEST_UI_TEST_PACKAGE: An XCode UI test package upload.
            status (string) --The upload's status.
            Must be one of the following values:
            FAILED: A failed status.
            INITIALIZED: An initialized status.
            PROCESSING: A processing status.
            SUCCEEDED: A succeeded status.
            url (string) --The pre-signed Amazon S3 URL that was used to store a file through a corresponding PUT request.
            metadata (string) --The upload's metadata. For example, for Android, this contains information that is parsed from the manifest and is displayed in the AWS Device Farm console after the associated app is uploaded.
            contentType (string) --The upload's content type (for example, 'application/octet-stream').
            message (string) --A message about the upload's result.
            
            
            
    :type arn: string
    """
    pass

def get_waiter():
    """
    """
    pass

def install_to_remote_access_session(remoteAccessSessionArn=None, appArn=None):
    """
    :param remoteAccessSessionArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the remote access session about which you are requesting information.
            
    :type remoteAccessSessionArn: string
    :param appArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the app about which you are requesting information.
            
    :type appArn: string
    """
    pass

def list_artifacts(arn=None, type=None, nextToken=None):
    """
    :param arn: [REQUIRED]
            The Run, Job, Suite, or Test ARN.
            
    :type arn: string
    :param type: [REQUIRED]
            The artifacts' type.
            Allowed values include:
            FILE: The artifacts are files.
            LOG: The artifacts are logs.
            SCREENSHOT: The artifacts are screenshots.
            
    :type type: string
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type nextToken: string
    """
    pass

def list_device_pools(arn=None, type=None, nextToken=None):
    """
    :param arn: [REQUIRED]
            The project ARN.
            
    :type arn: string
    :param type: The device pools' type.
            Allowed values include:
            CURATED: A device pool that is created and managed by AWS Device Farm.
            PRIVATE: A device pool that is created and managed by the device pool developer.
            
    :type type: string
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type nextToken: string
    """
    pass

def list_devices(arn=None, nextToken=None):
    """
    :param arn: The Amazon Resource Name (ARN) of the project.
    :type arn: string
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type nextToken: string
    """
    pass

def list_jobs(arn=None, nextToken=None):
    """
    :param arn: [REQUIRED]
            The jobs' ARNs.
            
    :type arn: string
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type nextToken: string
    """
    pass

def list_offering_transactions(nextToken=None):
    """
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
            Return typedict
            ReturnsResponse Syntax{
              'offeringTransactions': [
                {
                  'offeringStatus': {
                    'type': 'PURCHASE'|'RENEW'|'SYSTEM',
                    'offering': {
                      'id': 'string',
                      'description': 'string',
                      'type': 'RECURRING',
                      'platform': 'ANDROID'|'IOS',
                      'recurringCharges': [
                        {
                          'cost': {
                            'amount': 123.0,
                            'currencyCode': 'USD'
                          },
                          'frequency': 'MONTHLY'
                        },
                      ]
                    },
                    'quantity': 123,
                    'effectiveOn': datetime(2015, 1, 1)
                  },
                  'transactionId': 'string',
                  'createdOn': datetime(2015, 1, 1),
                  'cost': {
                    'amount': 123.0,
                    'currencyCode': 'USD'
                  }
                },
              ],
              'nextToken': 'string'
            }
            Response Structure
            (dict) --Returns the transaction log of the specified offerings.
            offeringTransactions (list) --The audit log of subscriptions you have purchased and modified through AWS Device Farm.
            (dict) --Represents the metadata of an offering transaction.
            offeringStatus (dict) --The status of an offering transaction.
            type (string) --The type specified for the offering status.
            offering (dict) --Represents the metadata of an offering status.
            id (string) --The ID that corresponds to a device offering.
            description (string) --A string describing the offering.
            type (string) --The type of offering (e.g., 'RECURRING') for a device.
            platform (string) --The platform of the device (e.g., ANDROID or IOS).
            recurringCharges (list) --Specifies whether there are recurring charges for the offering.
            (dict) --Specifies whether charges for devices will be recurring.
            cost (dict) --The cost of the recurring charge.
            amount (float) --The numerical amount of an offering or transaction.
            currencyCode (string) --The currency code of a monetary amount. For example, USD means 'U.S. dollars.'
            frequency (string) --The frequency in which charges will recur.
            
            quantity (integer) --The number of available devices in the offering.
            effectiveOn (datetime) --The date on which the offering is effective.
            transactionId (string) --The transaction ID of the offering transaction.
            createdOn (datetime) --The date on which an offering transaction was created.
            cost (dict) --The cost of an offering transaction.
            amount (float) --The numerical amount of an offering or transaction.
            currencyCode (string) --The currency code of a monetary amount. For example, USD means 'U.S. dollars.'
            
            nextToken (string) --An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
            
            
    :type nextToken: string
    """
    pass

def list_offerings(nextToken=None):
    """
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
            Return typedict
            ReturnsResponse Syntax{
              'offerings': [
                {
                  'id': 'string',
                  'description': 'string',
                  'type': 'RECURRING',
                  'platform': 'ANDROID'|'IOS',
                  'recurringCharges': [
                    {
                      'cost': {
                        'amount': 123.0,
                        'currencyCode': 'USD'
                      },
                      'frequency': 'MONTHLY'
                    },
                  ]
                },
              ],
              'nextToken': 'string'
            }
            Response Structure
            (dict) --Represents the return values of the list of offerings.
            offerings (list) --A value representing the list offering results.
            (dict) --Represents the metadata of a device offering.
            id (string) --The ID that corresponds to a device offering.
            description (string) --A string describing the offering.
            type (string) --The type of offering (e.g., 'RECURRING') for a device.
            platform (string) --The platform of the device (e.g., ANDROID or IOS).
            recurringCharges (list) --Specifies whether there are recurring charges for the offering.
            (dict) --Specifies whether charges for devices will be recurring.
            cost (dict) --The cost of the recurring charge.
            amount (float) --The numerical amount of an offering or transaction.
            currencyCode (string) --The currency code of a monetary amount. For example, USD means 'U.S. dollars.'
            frequency (string) --The frequency in which charges will recur.
            
            
            nextToken (string) --An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
            
            
    :type nextToken: string
    """
    pass

def list_projects(arn=None, nextToken=None):
    """
    :param arn: Optional. If no Amazon Resource Name (ARN) is specified, then AWS Device Farm returns a list of all projects for the AWS account. You can also specify a project ARN.
    :type arn: string
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type nextToken: string
    """
    pass

def list_remote_access_sessions(arn=None, nextToken=None):
    """
    :param arn: [REQUIRED]
            The Amazon Resource Name (ARN) of the remote access session about which you are requesting information.
            
    :type arn: string
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type nextToken: string
    """
    pass

def list_runs(arn=None, nextToken=None):
    """
    :param arn: [REQUIRED]
            The Amazon Resource Name (ARN) of the project for which you want to list runs.
            
    :type arn: string
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type nextToken: string
    """
    pass

def list_samples(arn=None, nextToken=None):
    """
    :param arn: [REQUIRED]
            The Amazon Resource Name (ARN) of the project for which you want to list samples.
            
    :type arn: string
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type nextToken: string
    """
    pass

def list_suites(arn=None, nextToken=None):
    """
    :param arn: [REQUIRED]
            The suites' ARNs.
            
    :type arn: string
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type nextToken: string
    """
    pass

def list_tests(arn=None, nextToken=None):
    """
    :param arn: [REQUIRED]
            The tests' ARNs.
            
    :type arn: string
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type nextToken: string
    """
    pass

def list_unique_problems(arn=None, nextToken=None):
    """
    :param arn: [REQUIRED]
            The unique problems' ARNs.
            
    :type arn: string
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type nextToken: string
    """
    pass

def list_uploads(arn=None, nextToken=None):
    """
    :param arn: [REQUIRED]
            The Amazon Resource Name (ARN) of the project for which you want to list uploads.
            
    :type arn: string
    :param nextToken: An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
    :type nextToken: string
    """
    pass

def purchase_offering(offeringId=None, quantity=None):
    """
    :param offeringId: The ID of the offering.
    :type offeringId: string
    :param quantity: The number of device slots you wish to purchase in an offering request.
    :type quantity: integer
    """
    pass

def renew_offering(offeringId=None, quantity=None):
    """
    :param offeringId: The ID of a request to renew an offering.
    :type offeringId: string
    :param quantity: The quantity requested in an offering renewal.
    :type quantity: integer
    """
    pass

def schedule_run(projectArn=None, appArn=None, devicePoolArn=None, name=None, test=None, configuration=None):
    """
    :param projectArn: [REQUIRED]
            The ARN of the project for the run to be scheduled.
            
    :type projectArn: string
    :param appArn: The ARN of the app to schedule a run.
    :type appArn: string
    :param devicePoolArn: [REQUIRED]
            The ARN of the device pool for the run to be scheduled.
            
    :type devicePoolArn: string
    :param name: The name for the run to be scheduled.
    :type name: string
    :param test: [REQUIRED]
            Information about the test for the run to be scheduled.
            type (string) -- [REQUIRED]The test's type.
            Must be one of the following values:
            BUILTIN_FUZZ: The built-in fuzz type.
            BUILTIN_EXPLORER: For Android, an app explorer that will traverse an Android app, interacting with it and capturing screenshots at the same time.
            APPIUM_JAVA_JUNIT: The Appium Java JUnit type.
            APPIUM_JAVA_TESTNG: The Appium Java TestNG type.
            APPIUM_PYTHON: The Appium Python type.
            APPIUM_WEB_JAVA_JUNIT: The Appium Java JUnit type for Web apps.
            APPIUM_WEB_JAVA_TESTNG: The Appium Java TestNG type for Web apps.
            APPIUM_WEB_PYTHON: The Appium Python type for Web apps.
            CALABASH: The Calabash type.
            INSTRUMENTATION: The Instrumentation type.
            UIAUTOMATION: The uiautomation type.
            UIAUTOMATOR: The uiautomator type.
            XCTEST: The XCode test type.
            XCTEST_UI: The XCode UI test type.
            testPackageArn (string) --The ARN of the uploaded test that will be run.
            filter (string) --The test's filter.
            parameters (dict) --The test's parameters, such as test framework parameters and fixture settings.
            (string) --
            (string) --
            
            
    :type test: dict
    :param configuration: Information about the settings for the run to be scheduled.
            extraDataPackageArn (string) --The ARN of the extra data for the run. The extra data is a .zip file that AWS Device Farm will extract to external data for Android or the app's sandbox for iOS.
            networkProfileArn (string) --Reserved for internal use.
            locale (string) --Information about the locale that is used for the run.
            location (dict) --Information about the location that is used for the run.
            latitude (float) -- [REQUIRED]The latitude.
            longitude (float) -- [REQUIRED]The longitude.
            radios (dict) --Information about the radio states for the run.
            wifi (boolean) --True if Wi-Fi is enabled at the beginning of the test; otherwise, false.
            bluetooth (boolean) --True if Bluetooth is enabled at the beginning of the test; otherwise, false.
            nfc (boolean) --True if NFC is enabled at the beginning of the test; otherwise, false.
            gps (boolean) --True if GPS is enabled at the beginning of the test; otherwise, false.
            auxiliaryApps (list) --A list of auxiliary apps for the run.
            (string) --
            billingMethod (string) --Specifies the billing method for a test run: metered or unmetered . If the parameter is not specified, the default value is metered .
            
    :type configuration: dict
    """
    pass

def stop_remote_access_session(arn=None):
    """
    :param arn: [REQUIRED]
            The Amazon Resource Name (ARN) of the remote access session you wish to stop.
            Return typedict
            ReturnsResponse Syntax{
              'remoteAccessSession': {
                'arn': 'string',
                'name': 'string',
                'created': datetime(2015, 1, 1),
                'status': 'PENDING'|'PENDING_CONCURRENCY'|'PENDING_DEVICE'|'PROCESSING'|'SCHEDULING'|'PREPARING'|'RUNNING'|'COMPLETED'|'STOPPING',
                'result': 'PENDING'|'PASSED'|'WARNED'|'FAILED'|'SKIPPED'|'ERRORED'|'STOPPED',
                'message': 'string',
                'started': datetime(2015, 1, 1),
                'stopped': datetime(2015, 1, 1),
                'device': {
                  'arn': 'string',
                  'name': 'string',
                  'manufacturer': 'string',
                  'model': 'string',
                  'formFactor': 'PHONE'|'TABLET',
                  'platform': 'ANDROID'|'IOS',
                  'os': 'string',
                  'cpu': {
                    'frequency': 'string',
                    'architecture': 'string',
                    'clock': 123.0
                  },
                  'resolution': {
                    'width': 123,
                    'height': 123
                  },
                  'heapSize': 123,
                  'memory': 123,
                  'image': 'string',
                  'carrier': 'string',
                  'radio': 'string',
                  'remoteAccessEnabled': True|False,
                  'fleetType': 'string',
                  'fleetName': 'string'
                },
                'billingMethod': 'METERED'|'UNMETERED',
                'deviceMinutes': {
                  'total': 123.0,
                  'metered': 123.0,
                  'unmetered': 123.0
                },
                'endpoint': 'string'
              }
            }
            Response Structure
            (dict) --Represents the response from the server that describes the remote access session when AWS Device Farm stops the session.
            remoteAccessSession (dict) --A container representing the metadata from the service about the remote access session you are stopping.
            arn (string) --The Amazon Resource Name (ARN) of the remote access session.
            name (string) --The name of the remote access session.
            created (datetime) --The date and time the remote access session was created.
            status (string) --The status of the remote access session. Can be any of the following:
            PENDING: A pending status.
            PENDING_CONCURRENCY: A pending concurrency status.
            PENDING_DEVICE: A pending device status.
            PROCESSING: A processing status.
            SCHEDULING: A scheduling status.
            PREPARING: A preparing status.
            RUNNING: A running status.
            COMPLETED: A completed status.
            STOPPING: A stopping status.
            result (string) --The result of the remote access session. Can be any of the following:
            PENDING: A pending condition.
            PASSED: A passing condition.
            WARNED: A warning condition.
            FAILED: A failed condition.
            SKIPPED: A skipped condition.
            ERRORED: An error condition.
            STOPPED: A stopped condition.
            message (string) --A message about the remote access session.
            started (datetime) --The date and time the remote access session was started.
            stopped (datetime) --The date and time the remote access session was stopped.
            device (dict) --Represents a device type that an app is tested against.
            arn (string) --The device's ARN.
            name (string) --The device's display name.
            manufacturer (string) --The device's manufacturer name.
            model (string) --The device's model name.
            formFactor (string) --The device's form factor.
            Allowed values include:
            PHONE: The phone form factor.
            TABLET: The tablet form factor.
            platform (string) --The device's platform.
            Allowed values include:
            ANDROID: The Android platform.
            IOS: The iOS platform.
            os (string) --The device's operating system type.
            cpu (dict) --Information about the device's CPU.
            frequency (string) --The CPU's frequency.
            architecture (string) --The CPU's architecture, for example x86 or ARM.
            clock (float) --The clock speed of the device's CPU, expressed in hertz (Hz). For example, a 1.2 GHz CPU is expressed as 1200000000.
            resolution (dict) --Represents the screen resolution of a device in height and width, expressed in pixels.
            width (integer) --The screen resolution's width, expressed in pixels.
            height (integer) --The screen resolution's height, expressed in pixels.
            heapSize (integer) --The device's heap size, expressed in bytes.
            memory (integer) --The device's total memory size, expressed in bytes.
            image (string) --The device's image name.
            carrier (string) --The device's carrier.
            radio (string) --The device's radio.
            remoteAccessEnabled (boolean) --Specifies whether remote access has been enabled for the specified device.
            fleetType (string) --The type of fleet to which this device belongs. Possible values for fleet type are PRIVATE and PUBLIC.
            fleetName (string) --The name of the fleet to which this device belongs.
            billingMethod (string) --The billing method of the remote access session. Possible values include METERED or UNMETERED . For more information about metered devices, see AWS Device Farm terminology .'
            deviceMinutes (dict) --Represents the total (metered or unmetered) minutes used by the resource to run tests. Contains the sum of minutes consumed by all children.
            total (float) --When specified, represents the total minutes used by the resource to run tests.
            metered (float) --When specified, represents only the sum of metered minutes used by the resource to run tests.
            unmetered (float) --When specified, represents only the sum of unmetered minutes used by the resource to run tests.
            endpoint (string) --The endpoint for the remote access sesssion.
            
            
            
    :type arn: string
    """
    pass

def stop_run(arn=None):
    """
    :param arn: [REQUIRED]
            Represents the Amazon Resource Name (ARN) of the Device Farm run you wish to stop.
            Return typedict
            ReturnsResponse Syntax{
              'run': {
                'arn': 'string',
                'name': 'string',
                'type': 'BUILTIN_FUZZ'|'BUILTIN_EXPLORER'|'APPIUM_JAVA_JUNIT'|'APPIUM_JAVA_TESTNG'|'APPIUM_PYTHON'|'APPIUM_WEB_JAVA_JUNIT'|'APPIUM_WEB_JAVA_TESTNG'|'APPIUM_WEB_PYTHON'|'CALABASH'|'INSTRUMENTATION'|'UIAUTOMATION'|'UIAUTOMATOR'|'XCTEST'|'XCTEST_UI',
                'platform': 'ANDROID'|'IOS',
                'created': datetime(2015, 1, 1),
                'status': 'PENDING'|'PENDING_CONCURRENCY'|'PENDING_DEVICE'|'PROCESSING'|'SCHEDULING'|'PREPARING'|'RUNNING'|'COMPLETED'|'STOPPING',
                'result': 'PENDING'|'PASSED'|'WARNED'|'FAILED'|'SKIPPED'|'ERRORED'|'STOPPED',
                'started': datetime(2015, 1, 1),
                'stopped': datetime(2015, 1, 1),
                'counters': {
                  'total': 123,
                  'passed': 123,
                  'failed': 123,
                  'warned': 123,
                  'errored': 123,
                  'stopped': 123,
                  'skipped': 123
                },
                'message': 'string',
                'totalJobs': 123,
                'completedJobs': 123,
                'billingMethod': 'METERED'|'UNMETERED',
                'deviceMinutes': {
                  'total': 123.0,
                  'metered': 123.0,
                  'unmetered': 123.0
                }
              }
            }
            Response Structure
            (dict) --Represents the results of your stop run attempt.
            run (dict) --Represents an app on a set of devices with a specific test and configuration.
            arn (string) --The run's ARN.
            name (string) --The run's name.
            type (string) --The run's type.
            Must be one of the following values:
            BUILTIN_FUZZ: The built-in fuzz type.
            BUILTIN_EXPLORER: For Android, an app explorer that will traverse an Android app, interacting with it and capturing screenshots at the same time.
            APPIUM_JAVA_JUNIT: The Appium Java JUnit type.
            APPIUM_JAVA_TESTNG: The Appium Java TestNG type.
            APPIUM_PYTHON: The Appium Python type.
            APPIUM_WEB_JAVA_JUNIT: The Appium Java JUnit type for Web apps.
            APPIUM_WEB_JAVA_TESTNG: The Appium Java TestNG type for Web apps.
            APPIUM_WEB_PYTHON: The Appium Python type for Web apps.
            CALABASH: The Calabash type.
            INSTRUMENTATION: The Instrumentation type.
            UIAUTOMATION: The uiautomation type.
            UIAUTOMATOR: The uiautomator type.
            XCTEST: The XCode test type.
            XCTEST_UI: The XCode UI test type.
            platform (string) --The run's platform.
            Allowed values include:
            ANDROID: The Android platform.
            IOS: The iOS platform.
            created (datetime) --When the run was created.
            status (string) --The run's status.
            Allowed values include:
            PENDING: A pending status.
            PENDING_CONCURRENCY: A pending concurrency status.
            PENDING_DEVICE: A pending device status.
            PROCESSING: A processing status.
            SCHEDULING: A scheduling status.
            PREPARING: A preparing status.
            RUNNING: A running status.
            COMPLETED: A completed status.
            STOPPING: A stopping status.
            result (string) --The run's result.
            Allowed values include:
            PENDING: A pending condition.
            PASSED: A passing condition.
            WARNED: A warning condition.
            FAILED: A failed condition.
            SKIPPED: A skipped condition.
            ERRORED: An error condition.
            STOPPED: A stopped condition.
            started (datetime) --The run's start time.
            stopped (datetime) --The run's stop time.
            counters (dict) --The run's result counters.
            total (integer) --The total number of entities.
            passed (integer) --The number of passed entities.
            failed (integer) --The number of failed entities.
            warned (integer) --The number of warned entities.
            errored (integer) --The number of errored entities.
            stopped (integer) --The number of stopped entities.
            skipped (integer) --The number of skipped entities.
            message (string) --A message about the run's result.
            totalJobs (integer) --The total number of jobs for the run.
            completedJobs (integer) --The total number of completed jobs.
            billingMethod (string) --Specifies the billing method for a test run: metered or unmetered . If the parameter is not specified, the default value is metered .
            deviceMinutes (dict) --Represents the total (metered or unmetered) minutes used by the test run.
            total (float) --When specified, represents the total minutes used by the resource to run tests.
            metered (float) --When specified, represents only the sum of metered minutes used by the resource to run tests.
            unmetered (float) --When specified, represents only the sum of unmetered minutes used by the resource to run tests.
            
            
            
    :type arn: string
    """
    pass

def update_device_pool(arn=None, name=None, description=None, rules=None):
    """
    :param arn: [REQUIRED]
            The Amazon Resourc Name (ARN) of the Device Farm device pool you wish to update.
            
    :type arn: string
    :param name: A string representing the name of the device pool you wish to update.
    :type name: string
    :param description: A description of the device pool you wish to update.
    :type description: string
    :param rules: Represents the rules you wish to modify for the device pool. Updating rules is optional; however, if you choose to update rules for your request, the update will replace the existing rules.
            (dict) --Represents a condition for a device pool.
            attribute (string) --The rule's stringified attribute. For example, specify the value as '\'abc\'' .
            Allowed values include:
            ARN: The ARN.
            FORM_FACTOR: The form factor (for example, phone or tablet).
            MANUFACTURER: The manufacturer.
            PLATFORM: The platform (for example, Android or iOS).
            operator (string) --The rule's operator.
            EQUALS: The equals operator.
            GREATER_THAN: The greater-than operator.
            IN: The in operator.
            LESS_THAN: The less-than operator.
            NOT_IN: The not-in operator.
            value (string) --The rule's value.
            
            
    :type rules: list
    """
    pass

def update_project(arn=None, name=None):
    """
    :param arn: [REQUIRED]
            The Amazon Resource Name (ARN) of the project whose name you wish to update.
            
    :type arn: string
    :param name: A string representing the new name of the project that you are updating.
    :type name: string
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def add_application_input(ApplicationName=None, CurrentApplicationVersionId=None, Input=None):
    """
    :param ApplicationName: [REQUIRED]
            Name of your existing Amazon Kinesis Analytics application to which you want to add the streaming source.
            
    :type ApplicationName: string
    :param CurrentApplicationVersionId: [REQUIRED]
            Current version of your Amazon Kinesis Analytics application. You can use the DescribeApplication operation to find the current application version.
            
    :type CurrentApplicationVersionId: integer
    :param Input: [REQUIRED]
            When you configure the application input, you specify the streaming source, the in-application stream name that is created, and the mapping between the two. For more information, see Configuring Application Input .
            NamePrefix (string) -- [REQUIRED]Name prefix to use when creating in-application stream. Suppose you specify a prefix 'MyInApplicationStream'. Kinesis Analytics will then create one or more (as per the InputParallelism count you specified) in-application streams with names 'MyInApplicationStream_001', 'MyInApplicationStream_002' and so on.
            KinesisStreamsInput (dict) --If the streaming source is an Amazon Kinesis stream, identifies the stream's Amazon Resource Name (ARN) and an IAM role that enables Amazon Kinesis Analytics to access the stream on your behalf.
            ResourceARN (string) -- [REQUIRED]ARN of the input Amazon Kinesis stream to read.
            RoleARN (string) -- [REQUIRED]ARN of the IAM role that Amazon Kinesis Analytics can assume to access the stream on your behalf. You need to grant the necessary permissions to this role.
            KinesisFirehoseInput (dict) --If the streaming source is an Amazon Kinesis Firehose delivery stream, identifies the Firehose delivery stream's ARN and an IAM role that enables Amazon Kinesis Analytics to access the stream on your behalf.
            ResourceARN (string) -- [REQUIRED]ARN of the input Firehose delivery stream.
            RoleARN (string) -- [REQUIRED]ARN of the IAM role that Amazon Kinesis Analytics can assume to access the stream on your behalf. You need to make sure the role has necessary permissions to access the stream.
            InputParallelism (dict) --Describes the number of in-application streams to create.
            Data from your source will be routed to these in-application input streams.
            (see Configuring Application Input .
            Count (integer) --Number of in-application streams to create. For more information, see Limits .
            InputSchema (dict) -- [REQUIRED]Describes the format of the data in the streaming source, and how each data element maps to corresponding columns in the in-application stream that is being created.
            Also used to describe the format of the reference data source.
            RecordFormat (dict) -- [REQUIRED]Specifies the format of the records on the streaming source.
            RecordFormatType (string) -- [REQUIRED]The type of record format.
            MappingParameters (dict) --When configuring application input at the time of creating or updating an application, provides additional mapping information specific to the record format (such as JSON, CSV, or record fields delimited by some delimiter) on the streaming source.
            JSONMappingParameters (dict) --Provides additional mapping information when JSON is the record format on the streaming source.
            RecordRowPath (string) -- [REQUIRED]Path to the top-level parent that contains the records.
            For example, consider the following JSON record:
            In the RecordRowPath , '$' refers to the root and path '$.vehicle.Model' refers to the specific 'Model' key in the JSON.
            CSVMappingParameters (dict) --Provides additional mapping information when the record format uses delimiters (for example, CSV).
            RecordRowDelimiter (string) -- [REQUIRED]Row delimiter. For example, in a CSV format, 'n' is the typical row delimiter.
            RecordColumnDelimiter (string) -- [REQUIRED]Column delimiter. For example, in a CSV format, a comma (',') is the typical column delimiter.
            
            RecordEncoding (string) --Specifies the encoding of the records in the streaming source. For example, UTF-8.
            RecordColumns (list) -- [REQUIRED]A list of RecordColumn objects.
            (dict) --Describes the mapping of each data element in the streaming source to the corresponding column in the in-application stream.
            Also used to describe the format of the reference data source.
            Name (string) -- [REQUIRED]Name of the column created in the in-application input stream or reference table.
            Mapping (string) --Reference to the data element in the streaming input of the reference data source.
            SqlType (string) -- [REQUIRED]Type of column created in the in-application input stream or reference table.
            
            
            
    :type Input: dict
    """
    pass

def add_application_output(ApplicationName=None, CurrentApplicationVersionId=None, Output=None):
    """
    :param ApplicationName: [REQUIRED]
            Name of the application to which you want to add the output configuration.
            
    :type ApplicationName: string
    :param CurrentApplicationVersionId: [REQUIRED]
            Version of the application to which you want add the output configuration. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ConcurrentModificationException is returned.
            
    :type CurrentApplicationVersionId: integer
    :param Output: [REQUIRED]
            An array of objects, each describing one output configuration. In the output configuration, you specify the name of an in-application stream, a destination (that is, an Amazon Kinesis stream or an Amazon Kinesis Firehose delivery stream), and record the formation to use when writing to the destination.
            Name (string) -- [REQUIRED]Name of the in-application stream.
            KinesisStreamsOutput (dict) --Identifies an Amazon Kinesis stream as the destination.
            ResourceARN (string) -- [REQUIRED]ARN of the destination Amazon Kinesis stream to write to.
            RoleARN (string) -- [REQUIRED]ARN of the IAM role that Amazon Kinesis Analytics can assume to write to the destination stream on your behalf. You need to grant the necessary permissions to this role.
            KinesisFirehoseOutput (dict) --Identifies an Amazon Kinesis Firehose delivery stream as the destination.
            ResourceARN (string) -- [REQUIRED]ARN of the destination Amazon Kinesis Firehose delivery stream to write to.
            RoleARN (string) -- [REQUIRED]ARN of the IAM role that Amazon Kinesis Analytics can assume to write to the destination stream on your behalf. You need to grant the necessary permissions to this role.
            DestinationSchema (dict) -- [REQUIRED]Describes the data format when records are written to the destination. For more information, see Configuring Application Output .
            RecordFormatType (string) --Specifies the format of the records on the output stream.
            
            
    :type Output: dict
    """
    pass

def add_application_reference_data_source(ApplicationName=None, CurrentApplicationVersionId=None, ReferenceDataSource=None):
    """
    :param ApplicationName: [REQUIRED]
            Name of an existing application.
            
    :type ApplicationName: string
    :param CurrentApplicationVersionId: [REQUIRED]
            Version of the application for which you are adding the reference data source. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ConcurrentModificationException is returned.
            
    :type CurrentApplicationVersionId: integer
    :param ReferenceDataSource: [REQUIRED]
            The reference data source can be an object in your Amazon S3 bucket. Amazon Kinesis Analytics reads the object and copies the data into the in-application table that is created. You provide an S3 bucket, object key name, and the resulting in-application table that is created. You must also provide an IAM role with the necessary permissions that Amazon Kinesis Analytics can assume to read the object from your S3 bucket on your behalf.
            TableName (string) -- [REQUIRED]Name of the in-application table to create.
            S3ReferenceDataSource (dict) --Identifies the S3 bucket and object that contains the reference data. Also identifies the IAM role Amazon Kinesis Analytics can assume to read this object on your behalf.
            An Amazon Kinesis Analytics application loads reference data only once. If the data changes, you call the UpdateApplication operation to trigger reloading of data into your application.
            BucketARN (string) -- [REQUIRED]Amazon Resource Name (ARN) of the S3 bucket.
            FileKey (string) -- [REQUIRED]Object key name containing reference data.
            ReferenceRoleARN (string) -- [REQUIRED]ARN of the IAM role that the service can assume to read data on your behalf. This role must have permission for the s3:GetObject action on the object and trust policy that allows Amazon Kinesis Analytics service principal to assume this role.
            ReferenceSchema (dict) -- [REQUIRED]Describes the format of the data in the streaming source, and how each data element maps to corresponding columns created in the in-application stream.
            RecordFormat (dict) -- [REQUIRED]Specifies the format of the records on the streaming source.
            RecordFormatType (string) -- [REQUIRED]The type of record format.
            MappingParameters (dict) --When configuring application input at the time of creating or updating an application, provides additional mapping information specific to the record format (such as JSON, CSV, or record fields delimited by some delimiter) on the streaming source.
            JSONMappingParameters (dict) --Provides additional mapping information when JSON is the record format on the streaming source.
            RecordRowPath (string) -- [REQUIRED]Path to the top-level parent that contains the records.
            For example, consider the following JSON record:
            In the RecordRowPath , '$' refers to the root and path '$.vehicle.Model' refers to the specific 'Model' key in the JSON.
            CSVMappingParameters (dict) --Provides additional mapping information when the record format uses delimiters (for example, CSV).
            RecordRowDelimiter (string) -- [REQUIRED]Row delimiter. For example, in a CSV format, 'n' is the typical row delimiter.
            RecordColumnDelimiter (string) -- [REQUIRED]Column delimiter. For example, in a CSV format, a comma (',') is the typical column delimiter.
            
            RecordEncoding (string) --Specifies the encoding of the records in the streaming source. For example, UTF-8.
            RecordColumns (list) -- [REQUIRED]A list of RecordColumn objects.
            (dict) --Describes the mapping of each data element in the streaming source to the corresponding column in the in-application stream.
            Also used to describe the format of the reference data source.
            Name (string) -- [REQUIRED]Name of the column created in the in-application input stream or reference table.
            Mapping (string) --Reference to the data element in the streaming input of the reference data source.
            SqlType (string) -- [REQUIRED]Type of column created in the in-application input stream or reference table.
            
            
            
    :type ReferenceDataSource: dict
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_application(ApplicationName=None, ApplicationDescription=None, Inputs=None, Outputs=None, ApplicationCode=None):
    """
    :param ApplicationName: [REQUIRED]
            Name of your Amazon Kinesis Analytics application (for example, sample-app ).
            
    :type ApplicationName: string
    :param ApplicationDescription: Summary description of the application.
    :type ApplicationDescription: string
    :param Inputs: Use this parameter to configure the application input.
            You can configure your application to receive input from a single streaming source. In this configuration, you map this streaming source to an in-application stream that is created. Your application code can then query the in-application stream like a table (you can think of it as a constantly updating table).
            For the streaming source, you provide its Amazon Resource Name (ARN) and format of data on the stream (for example, JSON, CSV, etc). You also must provide an IAM role that Amazon Kinesis Analytics can assume to read this stream on your behalf.
            To create the in-application stream, you need to specify a schema to transform your data into a schematized version used in SQL. In the schema, you provide the necessary mapping of the data elements in the streaming source to record columns in the in-app stream.
            (dict) --When you configure the application input, you specify the streaming source, the in-application stream name that is created, and the mapping between the two. For more information, see Configuring Application Input .
            NamePrefix (string) -- [REQUIRED]Name prefix to use when creating in-application stream. Suppose you specify a prefix 'MyInApplicationStream'. Kinesis Analytics will then create one or more (as per the InputParallelism count you specified) in-application streams with names 'MyInApplicationStream_001', 'MyInApplicationStream_002' and so on.
            KinesisStreamsInput (dict) --If the streaming source is an Amazon Kinesis stream, identifies the stream's Amazon Resource Name (ARN) and an IAM role that enables Amazon Kinesis Analytics to access the stream on your behalf.
            ResourceARN (string) -- [REQUIRED]ARN of the input Amazon Kinesis stream to read.
            RoleARN (string) -- [REQUIRED]ARN of the IAM role that Amazon Kinesis Analytics can assume to access the stream on your behalf. You need to grant the necessary permissions to this role.
            KinesisFirehoseInput (dict) --If the streaming source is an Amazon Kinesis Firehose delivery stream, identifies the Firehose delivery stream's ARN and an IAM role that enables Amazon Kinesis Analytics to access the stream on your behalf.
            ResourceARN (string) -- [REQUIRED]ARN of the input Firehose delivery stream.
            RoleARN (string) -- [REQUIRED]ARN of the IAM role that Amazon Kinesis Analytics can assume to access the stream on your behalf. You need to make sure the role has necessary permissions to access the stream.
            InputParallelism (dict) --Describes the number of in-application streams to create.
            Data from your source will be routed to these in-application input streams.
            (see Configuring Application Input .
            Count (integer) --Number of in-application streams to create. For more information, see Limits .
            InputSchema (dict) -- [REQUIRED]Describes the format of the data in the streaming source, and how each data element maps to corresponding columns in the in-application stream that is being created.
            Also used to describe the format of the reference data source.
            RecordFormat (dict) -- [REQUIRED]Specifies the format of the records on the streaming source.
            RecordFormatType (string) -- [REQUIRED]The type of record format.
            MappingParameters (dict) --When configuring application input at the time of creating or updating an application, provides additional mapping information specific to the record format (such as JSON, CSV, or record fields delimited by some delimiter) on the streaming source.
            JSONMappingParameters (dict) --Provides additional mapping information when JSON is the record format on the streaming source.
            RecordRowPath (string) -- [REQUIRED]Path to the top-level parent that contains the records.
            For example, consider the following JSON record:
            In the RecordRowPath , '$' refers to the root and path '$.vehicle.Model' refers to the specific 'Model' key in the JSON.
            CSVMappingParameters (dict) --Provides additional mapping information when the record format uses delimiters (for example, CSV).
            RecordRowDelimiter (string) -- [REQUIRED]Row delimiter. For example, in a CSV format, 'n' is the typical row delimiter.
            RecordColumnDelimiter (string) -- [REQUIRED]Column delimiter. For example, in a CSV format, a comma (',') is the typical column delimiter.
            
            RecordEncoding (string) --Specifies the encoding of the records in the streaming source. For example, UTF-8.
            RecordColumns (list) -- [REQUIRED]A list of RecordColumn objects.
            (dict) --Describes the mapping of each data element in the streaming source to the corresponding column in the in-application stream.
            Also used to describe the format of the reference data source.
            Name (string) -- [REQUIRED]Name of the column created in the in-application input stream or reference table.
            Mapping (string) --Reference to the data element in the streaming input of the reference data source.
            SqlType (string) -- [REQUIRED]Type of column created in the in-application input stream or reference table.
            
            
            
    :type Inputs: list
    :param Outputs: You can configure application output to write data from any of the in-application streams to up to five destinations.
            These destinations can be Amazon Kinesis streams, Amazon Kinesis Firehose delivery streams, or both.
            In the configuration, you specify the in-application stream name, the destination stream Amazon Resource Name (ARN), and the format to use when writing data. You must also provide an IAM role that Amazon Kinesis Analytics can assume to write to the destination stream on your behalf.
            In the output configuration, you also provide the output stream Amazon Resource Name (ARN) and the format of data in the stream (for example, JSON, CSV). You also must provide an IAM role that Amazon Kinesis Analytics can assume to write to this stream on your behalf.
            (dict) --Describes application output configuration in which you identify an in-application stream and a destination where you want the in-application stream data to be written. The destination can be an Amazon Kinesis stream or an Amazon Kinesis Firehose delivery stream.
            You can configure your application to write output to up to five destinations.
            Name (string) -- [REQUIRED]Name of the in-application stream.
            KinesisStreamsOutput (dict) --Identifies an Amazon Kinesis stream as the destination.
            ResourceARN (string) -- [REQUIRED]ARN of the destination Amazon Kinesis stream to write to.
            RoleARN (string) -- [REQUIRED]ARN of the IAM role that Amazon Kinesis Analytics can assume to write to the destination stream on your behalf. You need to grant the necessary permissions to this role.
            KinesisFirehoseOutput (dict) --Identifies an Amazon Kinesis Firehose delivery stream as the destination.
            ResourceARN (string) -- [REQUIRED]ARN of the destination Amazon Kinesis Firehose delivery stream to write to.
            RoleARN (string) -- [REQUIRED]ARN of the IAM role that Amazon Kinesis Analytics can assume to write to the destination stream on your behalf. You need to grant the necessary permissions to this role.
            DestinationSchema (dict) -- [REQUIRED]Describes the data format when records are written to the destination. For more information, see Configuring Application Output .
            RecordFormatType (string) --Specifies the format of the records on the output stream.
            
            
    :type Outputs: list
    :param ApplicationCode: One or more SQL statements that read input data, transform it, and generate output. For example, you can write a SQL statement that reads input data and generates a running average of the number of advertisement clicks by vendor.
            You can also provide a series of SQL statements, where output of one statement can be used as the input for the next statement.
            Note that the application code must create the streams with names specified in the Outputs . For example, if your Outputs defines output streams named ExampleOutputStream1 and ExampleOutputStream2 , then your application code must create these streams.
            
    :type ApplicationCode: string
    """
    pass

def delete_application(ApplicationName=None, CreateTimestamp=None):
    """
    :param ApplicationName: [REQUIRED]
            Name of the Amazon Kinesis Analytics application to delete.
            
    :type ApplicationName: string
    :param CreateTimestamp: [REQUIRED]
            You can use the DescribeApplication operation to get this value.
            
    :type CreateTimestamp: datetime
    """
    pass

def delete_application_output(ApplicationName=None, CurrentApplicationVersionId=None, OutputId=None):
    """
    :param ApplicationName: [REQUIRED]
            Amazon Kinesis Analytics application name.
            
    :type ApplicationName: string
    :param CurrentApplicationVersionId: [REQUIRED]
            Amazon Kinesis Analytics application version. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ConcurrentModificationException is returned.
            
    :type CurrentApplicationVersionId: integer
    :param OutputId: [REQUIRED]
            The ID of the configuration to delete. Each output configuration that is added to the application, either when the application is created or later using the AddApplicationOutput operation, has a unique ID. You need to provide the ID to uniquely identify the output configuration that you want to delete from the application configuration. You can use the DescribeApplication operation to get the specific OutputId .
            
    :type OutputId: string
    """
    pass

def delete_application_reference_data_source(ApplicationName=None, CurrentApplicationVersionId=None, ReferenceId=None):
    """
    :param ApplicationName: [REQUIRED]
            Name of an existing application.
            
    :type ApplicationName: string
    :param CurrentApplicationVersionId: [REQUIRED]
            Version of the application. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ConcurrentModificationException is returned.
            
    :type CurrentApplicationVersionId: integer
    :param ReferenceId: [REQUIRED]
            ID of the reference data source. When you add a reference data source to your application using the AddApplicationReferenceDataSource , Amazon Kinesis Analytics assigns an ID. You can use the DescribeApplication operation to get the reference ID.
            
    :type ReferenceId: string
    """
    pass

def describe_application(ApplicationName=None):
    """
    :param ApplicationName: [REQUIRED]
            Name of the application.
            Return typedict
            ReturnsResponse Syntax{
              'ApplicationDetail': {
                'ApplicationName': 'string',
                'ApplicationDescription': 'string',
                'ApplicationARN': 'string',
                'ApplicationStatus': 'DELETING'|'STARTING'|'STOPPING'|'READY'|'RUNNING'|'UPDATING',
                'CreateTimestamp': datetime(2015, 1, 1),
                'LastUpdateTimestamp': datetime(2015, 1, 1),
                'InputDescriptions': [
                  {
                    'InputId': 'string',
                    'NamePrefix': 'string',
                    'InAppStreamNames': [
                      'string',
                    ],
                    'KinesisStreamsInputDescription': {
                      'ResourceARN': 'string',
                      'RoleARN': 'string'
                    },
                    'KinesisFirehoseInputDescription': {
                      'ResourceARN': 'string',
                      'RoleARN': 'string'
                    },
                    'InputSchema': {
                      'RecordFormat': {
                        'RecordFormatType': 'JSON'|'CSV',
                        'MappingParameters': {
                          'JSONMappingParameters': {
                            'RecordRowPath': 'string'
                          },
                          'CSVMappingParameters': {
                            'RecordRowDelimiter': 'string',
                            'RecordColumnDelimiter': 'string'
                          }
                        }
                      },
                      'RecordEncoding': 'string',
                      'RecordColumns': [
                        {
                          'Name': 'string',
                          'Mapping': 'string',
                          'SqlType': 'string'
                        },
                      ]
                    },
                    'InputParallelism': {
                      'Count': 123
                    },
                    'InputStartingPositionConfiguration': {
                      'InputStartingPosition': 'NOW'|'TRIM_HORIZON'|'LAST_STOPPED_POINT'
                    }
                  },
                ],
                'OutputDescriptions': [
                  {
                    'OutputId': 'string',
                    'Name': 'string',
                    'KinesisStreamsOutputDescription': {
                      'ResourceARN': 'string',
                      'RoleARN': 'string'
                    },
                    'KinesisFirehoseOutputDescription': {
                      'ResourceARN': 'string',
                      'RoleARN': 'string'
                    },
                    'DestinationSchema': {
                      'RecordFormatType': 'JSON'|'CSV'
                    }
                  },
                ],
                'ReferenceDataSourceDescriptions': [
                  {
                    'ReferenceId': 'string',
                    'TableName': 'string',
                    'S3ReferenceDataSourceDescription': {
                      'BucketARN': 'string',
                      'FileKey': 'string',
                      'ReferenceRoleARN': 'string'
                    },
                    'ReferenceSchema': {
                      'RecordFormat': {
                        'RecordFormatType': 'JSON'|'CSV',
                        'MappingParameters': {
                          'JSONMappingParameters': {
                            'RecordRowPath': 'string'
                          },
                          'CSVMappingParameters': {
                            'RecordRowDelimiter': 'string',
                            'RecordColumnDelimiter': 'string'
                          }
                        }
                      },
                      'RecordEncoding': 'string',
                      'RecordColumns': [
                        {
                          'Name': 'string',
                          'Mapping': 'string',
                          'SqlType': 'string'
                        },
                      ]
                    }
                  },
                ],
                'ApplicationCode': 'string',
                'ApplicationVersionId': 123
              }
            }
            Response Structure
            (dict) --
            ApplicationDetail (dict) --Provides a description of the application, such as the application Amazon Resource Name (ARN), status, latest version, and input and output configuration details.
            ApplicationName (string) --Name of the application.
            ApplicationDescription (string) --Description of the application.
            ApplicationARN (string) --ARN of the application.
            ApplicationStatus (string) --Status of the application.
            CreateTimestamp (datetime) --Timestamp when the application version was created.
            LastUpdateTimestamp (datetime) --Timestamp when the application was last updated.
            InputDescriptions (list) --Describes the application input configuration. For more information, see Configuring Application Input .
            (dict) --Describes the application input configuration. For more information, see Configuring Application Input .
            InputId (string) --Input ID associated with the application input. This is the ID that Amazon Kinesis Analytics assigns to each input configuration you add to your application.
            NamePrefix (string) --In-application name prefix.
            InAppStreamNames (list) --Returns the in-application stream names that are mapped to the stream source.
            (string) --
            KinesisStreamsInputDescription (dict) --If an Amazon Kinesis stream is configured as streaming source, provides Amazon Kinesis stream's ARN and an IAM role that enables Amazon Kinesis Analytics to access the stream on your behalf.
            ResourceARN (string) --Amazon Resource Name (ARN) of the Amazon Kinesis stream.
            RoleARN (string) --ARN of the IAM role that Amazon Kinesis Analytics can assume to access the stream.
            KinesisFirehoseInputDescription (dict) --If an Amazon Kinesis Firehose delivery stream is configured as a streaming source, provides the Firehose delivery stream's Amazon Resource Name (ARN) and an IAM role that enables Amazon Kinesis Analytics to access the stream on your behalf.
            ResourceARN (string) --Amazon Resource Name (ARN) of the Amazon Kinesis Firehose delivery stream.
            RoleARN (string) --ARN of the IAM role that Amazon Kinesis Analytics assumes to access the stream.
            InputSchema (dict) --Describes the format of the data in the streaming source, and how each data element maps to corresponding columns created in the in-application stream.
            RecordFormat (dict) --Specifies the format of the records on the streaming source.
            RecordFormatType (string) --The type of record format.
            MappingParameters (dict) --When configuring application input at the time of creating or updating an application, provides additional mapping information specific to the record format (such as JSON, CSV, or record fields delimited by some delimiter) on the streaming source.
            JSONMappingParameters (dict) --Provides additional mapping information when JSON is the record format on the streaming source.
            RecordRowPath (string) --Path to the top-level parent that contains the records.
            For example, consider the following JSON record:
            In the RecordRowPath , '$' refers to the root and path '$.vehicle.Model' refers to the specific 'Model' key in the JSON.
            CSVMappingParameters (dict) --Provides additional mapping information when the record format uses delimiters (for example, CSV).
            RecordRowDelimiter (string) --Row delimiter. For example, in a CSV format, 'n' is the typical row delimiter.
            RecordColumnDelimiter (string) --Column delimiter. For example, in a CSV format, a comma (',') is the typical column delimiter.
            
            RecordEncoding (string) --Specifies the encoding of the records in the streaming source. For example, UTF-8.
            RecordColumns (list) --A list of RecordColumn objects.
            (dict) --Describes the mapping of each data element in the streaming source to the corresponding column in the in-application stream.
            Also used to describe the format of the reference data source.
            Name (string) --Name of the column created in the in-application input stream or reference table.
            Mapping (string) --Reference to the data element in the streaming input of the reference data source.
            SqlType (string) --Type of column created in the in-application input stream or reference table.
            
            InputParallelism (dict) --Describes the configured parallelism (number of in-application streams mapped to the streaming source).
            Count (integer) --Number of in-application streams to create. For more information, see Limits .
            InputStartingPositionConfiguration (dict) --Point at which the application is configured to read from the input stream.
            InputStartingPosition (string) --The starting position on the stream.
            LATEST - Start reading just after the most recent record in the stream.
            TRIM_HORIZON - Start reading at the last untrimmed record in the stream, which is the oldest record available in the stream. This option is not available for an Amazon Kinesis Firehose delivery stream.
            LAST_STOPPED_POINT - Resume reading from where the application last stopped reading.
            
            
            OutputDescriptions (list) --Describes the application output configuration. For more information, see Configuring Application Output .
            (dict) --Describes the application output configuration, which includes the in-application stream name and the destination where the stream data is written. The destination can be an Amazon Kinesis stream or an Amazon Kinesis Firehose delivery stream.
            OutputId (string) --A unique identifier for the output configuration.
            Name (string) --Name of the in-application stream configured as output.
            KinesisStreamsOutputDescription (dict) --Describes Amazon Kinesis stream configured as the destination where output is written.
            ResourceARN (string) --Amazon Resource Name (ARN) of the Amazon Kinesis stream.
            RoleARN (string) --ARN of the IAM role that Amazon Kinesis Analytics can assume to access the stream.
            KinesisFirehoseOutputDescription (dict) --Describes the Amazon Kinesis Firehose delivery stream configured as the destination where output is written.
            ResourceARN (string) --Amazon Resource Name (ARN) of the Amazon Kinesis Firehose delivery stream.
            RoleARN (string) --ARN of the IAM role that Amazon Kinesis Analytics can assume to access the stream.
            DestinationSchema (dict) --Data format used for writing data to the destination.
            RecordFormatType (string) --Specifies the format of the records on the output stream.
            
            ReferenceDataSourceDescriptions (list) --Describes reference data sources configured for the application. For more information, see Configuring Application Input .
            (dict) --Describes the reference data source configured for an application.
            ReferenceId (string) --ID of the reference data source. This is the ID that Amazon Kinesis Analytics assigns when you add the reference data source to your application using the AddApplicationReferenceDataSource operation.
            TableName (string) --The in-application table name created by the specific reference data source configuration.
            S3ReferenceDataSourceDescription (dict) --Provides the S3 bucket name, the object key name that contains the reference data. It also provides the Amazon Resource Name (ARN) of the IAM role that Amazon Kinesis Analytics can assume to read the Amazon S3 object and populate the in-application reference table.
            BucketARN (string) --Amazon Resource Name (ARN) of the S3 bucket.
            FileKey (string) --Amazon S3 object key name.
            ReferenceRoleARN (string) --ARN of the IAM role that Amazon Kinesis Analytics can assume to read the Amazon S3 object on your behalf to populate the in-application reference table.
            ReferenceSchema (dict) --Describes the format of the data in the streaming source, and how each data element maps to corresponding columns created in the in-application stream.
            RecordFormat (dict) --Specifies the format of the records on the streaming source.
            RecordFormatType (string) --The type of record format.
            MappingParameters (dict) --When configuring application input at the time of creating or updating an application, provides additional mapping information specific to the record format (such as JSON, CSV, or record fields delimited by some delimiter) on the streaming source.
            JSONMappingParameters (dict) --Provides additional mapping information when JSON is the record format on the streaming source.
            RecordRowPath (string) --Path to the top-level parent that contains the records.
            For example, consider the following JSON record:
            In the RecordRowPath , '$' refers to the root and path '$.vehicle.Model' refers to the specific 'Model' key in the JSON.
            CSVMappingParameters (dict) --Provides additional mapping information when the record format uses delimiters (for example, CSV).
            RecordRowDelimiter (string) --Row delimiter. For example, in a CSV format, 'n' is the typical row delimiter.
            RecordColumnDelimiter (string) --Column delimiter. For example, in a CSV format, a comma (',') is the typical column delimiter.
            
            RecordEncoding (string) --Specifies the encoding of the records in the streaming source. For example, UTF-8.
            RecordColumns (list) --A list of RecordColumn objects.
            (dict) --Describes the mapping of each data element in the streaming source to the corresponding column in the in-application stream.
            Also used to describe the format of the reference data source.
            Name (string) --Name of the column created in the in-application input stream or reference table.
            Mapping (string) --Reference to the data element in the streaming input of the reference data source.
            SqlType (string) --Type of column created in the in-application input stream or reference table.
            
            
            ApplicationCode (string) --Returns the application code that you provided to perform data analysis on any of the in-application streams in your application.
            ApplicationVersionId (integer) --Provides the current application version.
            
            
            
    :type ApplicationName: string
    """
    pass

def discover_input_schema(ResourceARN=None, RoleARN=None, InputStartingPositionConfiguration=None):
    """
    :param ResourceARN: [REQUIRED]
            Amazon Resource Name (ARN) of the streaming source.
            
    :type ResourceARN: string
    :param RoleARN: [REQUIRED]
            ARN of the IAM role that Amazon Kinesis Analytics can assume to access the stream on your behalf.
            
    :type RoleARN: string
    :param InputStartingPositionConfiguration: [REQUIRED]
            Point at which you want Amazon Kinesis Analytics to start reading records from the specified streaming source discovery purposes.
            InputStartingPosition (string) --The starting position on the stream.
            LATEST - Start reading just after the most recent record in the stream.
            TRIM_HORIZON - Start reading at the last untrimmed record in the stream, which is the oldest record available in the stream. This option is not available for an Amazon Kinesis Firehose delivery stream.
            LAST_STOPPED_POINT - Resume reading from where the application last stopped reading.
            
    :type InputStartingPositionConfiguration: dict
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_applications(Limit=None, ExclusiveStartApplicationName=None):
    """
    :param Limit: Maximum number of applications to list.
    :type Limit: integer
    :param ExclusiveStartApplicationName: Name of the application to start the list with. When using pagination to retrieve the list, you don't need to specify this parameter in the first request. However, in subsequent requests, you add the last application name from the previous response to get the next page of applications.
    :type ExclusiveStartApplicationName: string
    """
    pass

def start_application(ApplicationName=None, InputConfigurations=None):
    """
    :param ApplicationName: [REQUIRED]
            Name of the application.
            
    :type ApplicationName: string
    :param InputConfigurations: [REQUIRED]
            Identifies the specific input, by ID, that the application starts consuming. Amazon Kinesis Analytics starts reading the streaming source associated with the input. You can also specify where in the streaming source you want Amazon Kinesis Analytics to start reading.
            (dict) --When you start your application, you provide this configuration, which identifies the input source and the point in the input source at which you want the application to start processing records.
            Id (string) -- [REQUIRED]Input source ID. You can get this ID by calling the DescribeApplication operation.
            InputStartingPositionConfiguration (dict) -- [REQUIRED]Point at which you want the application to start processing records from the streaming source.
            InputStartingPosition (string) --The starting position on the stream.
            LATEST - Start reading just after the most recent record in the stream.
            TRIM_HORIZON - Start reading at the last untrimmed record in the stream, which is the oldest record available in the stream. This option is not available for an Amazon Kinesis Firehose delivery stream.
            LAST_STOPPED_POINT - Resume reading from where the application last stopped reading.
            
            
    :type InputConfigurations: list
    """
    pass

def stop_application(ApplicationName=None):
    """
    :param ApplicationName: [REQUIRED]
            Name of the running application to stop.
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --
            
    :type ApplicationName: string
    """
    pass

def update_application(ApplicationName=None, CurrentApplicationVersionId=None, ApplicationUpdate=None):
    """
    :param ApplicationName: [REQUIRED]
            Name of the Kinesis Analytics application to update.
            
    :type ApplicationName: string
    :param CurrentApplicationVersionId: [REQUIRED]
            The current application version ID. You can use the DescribeApplication operation to get this value.
            
    :type CurrentApplicationVersionId: integer
    :param ApplicationUpdate: [REQUIRED]
            Describes application updates.
            InputUpdates (list) --Describes application input configuration updates.
            (dict) --Describes updates to a specific input configuration (identified by the InputId of an application).
            InputId (string) -- [REQUIRED]Input ID of the application input to be updated.
            NamePrefixUpdate (string) --Name prefix for in-application stream(s) that Kinesis Analytics creates for the specific streaming source.
            KinesisStreamsInputUpdate (dict) --If a Amazon Kinesis stream is the streaming source to be updated, provides an updated stream ARN and IAM role ARN.
            ResourceARNUpdate (string) --Amazon Resource Name (ARN) of the input Amazon Kinesis stream to read.
            RoleARNUpdate (string) --ARN of the IAM role that Amazon Kinesis Analytics can assume to access the stream on your behalf. You need to grant the necessary permissions to this role.
            KinesisFirehoseInputUpdate (dict) --If an Amazon Kinesis Firehose delivery stream is the streaming source to be updated, provides an updated stream Amazon Resource Name (ARN) and IAM role ARN.
            ResourceARNUpdate (string) --ARN of the input Amazon Kinesis Firehose delivery stream to read.
            RoleARNUpdate (string) --Amazon Resource Name (ARN) of the IAM role that Amazon Kinesis Analytics can assume to access the stream on your behalf. You need to grant necessary permissions to this role.
            InputSchemaUpdate (dict) --Describes the data format on the streaming source, and how record elements on the streaming source map to columns of the in-application stream that is created.
            RecordFormatUpdate (dict) --Specifies the format of the records on the streaming source.
            RecordFormatType (string) -- [REQUIRED]The type of record format.
            MappingParameters (dict) --When configuring application input at the time of creating or updating an application, provides additional mapping information specific to the record format (such as JSON, CSV, or record fields delimited by some delimiter) on the streaming source.
            JSONMappingParameters (dict) --Provides additional mapping information when JSON is the record format on the streaming source.
            RecordRowPath (string) -- [REQUIRED]Path to the top-level parent that contains the records.
            For example, consider the following JSON record:
            In the RecordRowPath , '$' refers to the root and path '$.vehicle.Model' refers to the specific 'Model' key in the JSON.
            CSVMappingParameters (dict) --Provides additional mapping information when the record format uses delimiters (for example, CSV).
            RecordRowDelimiter (string) -- [REQUIRED]Row delimiter. For example, in a CSV format, 'n' is the typical row delimiter.
            RecordColumnDelimiter (string) -- [REQUIRED]Column delimiter. For example, in a CSV format, a comma (',') is the typical column delimiter.
            
            RecordEncodingUpdate (string) --Specifies the encoding of the records in the streaming source. For example, UTF-8.
            RecordColumnUpdates (list) --A list of RecordColumn objects. Each object describes the mapping of the streaming source element to the corresponding column in the in-application stream.
            (dict) --Describes the mapping of each data element in the streaming source to the corresponding column in the in-application stream.
            Also used to describe the format of the reference data source.
            Name (string) -- [REQUIRED]Name of the column created in the in-application input stream or reference table.
            Mapping (string) --Reference to the data element in the streaming input of the reference data source.
            SqlType (string) -- [REQUIRED]Type of column created in the in-application input stream or reference table.
            
            InputParallelismUpdate (dict) --Describes the parallelism updates (the number in-application streams Kinesis Analytics creates for the specific streaming source).
            CountUpdate (integer) --Number of in-application streams to create for the specified streaming source.
            
            ApplicationCodeUpdate (string) --Describes application code updates.
            OutputUpdates (list) --Describes application output configuration updates.
            (dict) --Describes updates to the output configuration identified by the OutputId .
            OutputId (string) -- [REQUIRED]Identifies the specific output configuration that you want to update.
            NameUpdate (string) --If you want to specify a different in-application stream for this output configuration, use this field to specify the new in-application stream name.
            KinesisStreamsOutputUpdate (dict) --Describes an Amazon Kinesis stream as the destination for the output.
            ResourceARNUpdate (string) --Amazon Resource Name (ARN) of the Amazon Kinesis stream where you want to write the output.
            RoleARNUpdate (string) --ARN of the IAM role that Amazon Kinesis Analytics can assume to access the stream on your behalf. You need to grant the necessary permissions to this role.
            KinesisFirehoseOutputUpdate (dict) --Describes a Amazon Kinesis Firehose delivery stream as the destination for the output.
            ResourceARNUpdate (string) --Amazon Resource Name (ARN) of the Amazon Kinesis Firehose delivery stream to write to.
            RoleARNUpdate (string) --ARN of the IAM role that Amazon Kinesis Analytics can assume to access the stream on your behalf. You need to grant necessary permissions to this role.
            DestinationSchemaUpdate (dict) --Describes the data format when records are written to the destination. For more information, see Configuring Application Output .
            RecordFormatType (string) --Specifies the format of the records on the output stream.
            
            ReferenceDataSourceUpdates (list) --Describes application reference data source updates.
            (dict) --When you update a reference data source configuration for an application, this object provides all the updated values (such as the source bucket name and object key name), the in-application table name that is created, and updated mapping information that maps the data in the Amazon S3 object to the in-application reference table that is created.
            ReferenceId (string) -- [REQUIRED]ID of the reference data source being updated. You can use the DescribeApplication operation to get this value.
            TableNameUpdate (string) --In-application table name that is created by this update.
            S3ReferenceDataSourceUpdate (dict) --Describes the S3 bucket name, object key name, and IAM role that Amazon Kinesis Analytics can assume to read the Amazon S3 object on your behalf and populate the in-application reference table.
            BucketARNUpdate (string) --Amazon Resource Name (ARN) of the S3 bucket.
            FileKeyUpdate (string) --Object key name.
            ReferenceRoleARNUpdate (string) --ARN of the IAM role that Amazon Kinesis Analytics can assume to read the Amazon S3 object and populate the in-application.
            ReferenceSchemaUpdate (dict) --Describes the format of the data in the streaming source, and how each data element maps to corresponding columns created in the in-application stream.
            RecordFormat (dict) -- [REQUIRED]Specifies the format of the records on the streaming source.
            RecordFormatType (string) -- [REQUIRED]The type of record format.
            MappingParameters (dict) --When configuring application input at the time of creating or updating an application, provides additional mapping information specific to the record format (such as JSON, CSV, or record fields delimited by some delimiter) on the streaming source.
            JSONMappingParameters (dict) --Provides additional mapping information when JSON is the record format on the streaming source.
            RecordRowPath (string) -- [REQUIRED]Path to the top-level parent that contains the records.
            For example, consider the following JSON record:
            In the RecordRowPath , '$' refers to the root and path '$.vehicle.Model' refers to the specific 'Model' key in the JSON.
            CSVMappingParameters (dict) --Provides additional mapping information when the record format uses delimiters (for example, CSV).
            RecordRowDelimiter (string) -- [REQUIRED]Row delimiter. For example, in a CSV format, 'n' is the typical row delimiter.
            RecordColumnDelimiter (string) -- [REQUIRED]Column delimiter. For example, in a CSV format, a comma (',') is the typical column delimiter.
            
            RecordEncoding (string) --Specifies the encoding of the records in the streaming source. For example, UTF-8.
            RecordColumns (list) -- [REQUIRED]A list of RecordColumn objects.
            (dict) --Describes the mapping of each data element in the streaming source to the corresponding column in the in-application stream.
            Also used to describe the format of the reference data source.
            Name (string) -- [REQUIRED]Name of the column created in the in-application input stream or reference table.
            Mapping (string) --Reference to the data element in the streaming input of the reference data source.
            SqlType (string) -- [REQUIRED]Type of column created in the in-application input stream or reference table.
            
            
            
            
    :type ApplicationUpdate: dict
    """
    pass

